{stdenv, fetchFromGitHub
, ninja, meson , pkgconfig
, libusb, readline, libewf, perl, zlib, openssl
, gtk2 ? null, vte ? null, gtkdialog ? null
, python ? null
, ruby ? null
, lua ? null
, useX11, rubyBindings, pythonBindings, luaBindings
}:

assert useX11 -> (gtk2 != null && vte != null && gtkdialog != null);
assert rubyBindings -> ruby != null;
assert pythonBindings -> python != null;


let
  inherit (stdenv.lib) optional;
  #<generated>
  # DO NOT EDIT! Automatically generated by ./update.py
  version_commit = "18681";
  gittap = "2.7.0";
  gittip = "6e08e452a7ec231a73997c44b4ff556c2998c7d9";
  version = "2.7.0";
  sha256 = "1a9z8w897256dhh3yhyfnshz3n2nrc4plc2i06cm5sznhl6x9xfx";
  cs_tip = "ec8a5ce98fa0422a395489ed47da912b15d77441";
  cs_sha256 = "080a64bqck28a2xfjwz29ddcr8p6hc6gi67mgry3pca289qrkk3q";
  #</generated>
in
stdenv.mkDerivation rec {
  name = "radare2-${version}";

  src = fetchFromGitHub {
    owner = "radare";
    repo = "radare2";
    rev = version;
    inherit sha256;
  };

  postPatch = let
    capstone = fetchFromGitHub {
      owner = "aquynh";
      repo = "capstone";
      # version from $sourceRoot/shlr/Makefile
      rev = cs_tip;
      sha256 = cs_sha256;
    };
  in ''
    if ! grep -F "CS_TIP=${cs_tip}" shlr/Makefile; then echo "CS_TIP mismatch"; exit 1; fi
    ln -s ${capstone} shlr/capstone
  '';

  postInstall = ''
    ln -s $out/bin/radare2 $out/bin/r2
    install -D -m755 $src/binr/r2pm/r2pm $out/bin/r2pm
  '';

  mesonFlags = [
    "-Dr2_version_commit=${version_commit}"
    "-Dr2_gittap=${gittap}"
    "-Dr2_gittip=${gittip}"
  ];

  enableParallelBuilding = true;

  nativeBuildInputs = [ pkgconfig ninja meson ];
  buildInputs = [ readline libusb libewf perl zlib openssl]
    ++ optional useX11 [gtkdialog vte gtk2]
    ++ optional rubyBindings [ruby]
    ++ optional pythonBindings [python]
    ++ optional luaBindings [lua];

  meta = {
    description = "unix-like reverse engineering framework and commandline tools";
    homepage = http://radare.org/;
    license = stdenv.lib.licenses.gpl2Plus;
    maintainers = with stdenv.lib.maintainers; [raskin makefu mic92];
    platforms = with stdenv.lib.platforms; linux;
    inherit version;
  };
}
