# TODO check that no license information gets lost
{ config, lib, stdenv, python, cmake, vim, vimUtils, ruby
, which, fetchgit, llvmPackages, rustPlatform
, xkb_switch, fzf, skim
, python3, boost, icu, ncurses
, ycmd, rake
, pythonPackages, python3Packages
, substituteAll
, languagetool
, Cocoa, CoreFoundation, CoreServices
}:

let

  _skim = skim;

  inherit (vimUtils.override {inherit vim;}) buildVimPluginFrom2Nix;


# TL;DR
# * Add your plugin to ./vim-plugin-names
#   * sort -df ./vim-plugin-names > sorted && mv sorted vim-plugin-names
# * Regenerate via `nix-shell -I nixpkgs=/path/to/your/local/fork -p vimPlugins.pluginnames2nix --command "vim-plugin-names-to-nix +silent +'x! result'"`
# Note: pluginnames2nix will fetch any plugins in the file; to speed up the process,
#       update ./vim-plugin-names to contain only plugins which need generation
# Copy the generated expression(s) into this file from the ./result file.
# If plugin is complicated then make changes to ./vim2nix/additional-nix-code

# This attrs contains two sections:
# The first contains plugins added manually, the second contains plugins
# generated by call nix#ExportPluginsForNix.
# Documentation & usage see vim-utils.nix.
# attribute names should be the same as used by vim-pi to make dependency
# resolution work
self = rec {
  # This is not a plugin, it provides bin/vim-open-buffer-with-plugins-derivations
  # which recreates this the following derivations based on ./vim-plugin-names
  pluginnames2nix = vimUtils.pluginnames2Nix {
    name = "vim-plugin-names-to-nix";
    namefiles = [./vim-plugin-names];
  };

  # Section I
  vim-addon-vim2nix = vim2nix;

  vim2nix = buildVimPluginFrom2Nix { # use it to update plugins
    name = "vim2nix";
    src = ./vim2nix;
    dependencies = ["vim-addon-manager"];
  };


  # Section II
  # Update with vimUtils.vimPlugins.pluginnames2Nix command

  fzfWrapper = buildVimPluginFrom2Nix {
    name = fzf.name;
    src = fzf.src;
    dependencies = [];
  };

  skim = buildVimPluginFrom2Nix {
    name = _skim.name;
    src = _skim.vim;
    dependencies = [];
  };

  LanguageClient-neovim = let
    LanguageClient-neovim-src = fetchgit {
      url = "https://github.com/autozimu/LanguageClient-neovim";
      rev = "5015aa164dc9ad96a0f5fbadaf92a888d16bc0d9";
      sha256 = "1b3916al2y4hxmmlhqxw4cdliyd42xahc7wmgm8yq1gbvzbhdafg";
    };
    LanguageClient-neovim-bin = rustPlatform.buildRustPackage {
      name = "LanguageClient-neovim-bin";
      src = LanguageClient-neovim-src;

      cargoSha256 = "1vafyi650qdaq1f7fc8d4nzrv1i6iz28fs5z66hsnz4xkwb3qq9w";
      buildInputs = stdenv.lib.optionals stdenv.isDarwin [ CoreServices ];

      # FIXME: Use impure version of CoreFoundation because of missing symbols.
      #   Undefined symbols for architecture x86_64: "_CFURLResourceIsReachable"
      preConfigure = stdenv.lib.optionalString stdenv.isDarwin ''
        export NIX_LDFLAGS="-F${CoreFoundation}/Library/Frameworks -framework CoreFoundation $NIX_LDFLAGS"
      '';
    };
  in buildVimPluginFrom2Nix {
    name = "LanguageClient-neovim-2018-06-12";
    src = LanguageClient-neovim-src;

    dependencies = [];
    propogatedBuildInputs = [ LanguageClient-neovim-bin ];

    preFixup = ''
      substituteInPlace "$out"/share/vim-plugins/LanguageClient-neovim/autoload/LanguageClient.vim \
        --replace "let l:path = s:root . '/bin/'" "let l:path = '${LanguageClient-neovim-bin}' . '/bin/'"
    '';
  };

  # do not auto-update this one, as the name clashes with vim-snippets
  vim-docbk-snippets = buildVimPluginFrom2Nix {
    name = "vim-docbk-snippets-2017-11-02";
    src = fetchgit {
      url = "https://github.com/jhradilek/vim-snippets";
      rev = "69cce66defdf131958f152ea7a7b26c21ca9d009";
      sha256 = "1363b2fmv69axrl2hm74dmx51cqd8k7rk116890qllnapzw1zjgc";
    };
    dependencies = [];
  };

  # missing dependency, using additional-nix-code results in an invalid expression
  vimshell-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimshell-vim-2018-06-02";
    src = fetchgit {
      url = "https://github.com/shougo/vimshell.vim";
      rev = "03bf7673a5098918a533000d67dca97546695237";
      sha256 = "1ckxjap9kz8skbjchg561sqyd5y5qwacg8mabmniy78qa7i3qdzi";
    };
    dependencies = [ "vimproc-vim" ];
  };

  # --- generated packages bellow this line ---

  vim-auto-save = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-auto-save-2017-11-08";
    src = fetchgit {
      url = "https://github.com/907th/vim-auto-save";
      rev = "66643afb55a1fcd3a9b4336f868f58da45bff397";
      sha256 = "1qnsj520j2hm6znpqpdqmz11vw45avgj8g9djx3alqbnab8ryw0p";
    };
    dependencies = [];

  };

  vim-autoformat = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-autoformat-2018-05-28";
    src = fetchgit {
      url = "https://github.com/Chiel92/vim-autoformat";
      rev = "3c50ddb50635f7899b4339a64bc02333cdd24a4b";
      sha256 = "1zw7b3zxgsmj149z238qx2palqysdywqgsxgj2z37kc8is8dpdpy";
    };
    dependencies = [];

  };

  ctrlp-py-matcher = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ctrlp-py-matcher-2017-11-01";
    src = fetchgit {
      url = "https://github.com/FelikZ/ctrlp-py-matcher";
      rev = "cf63fd546f1e80dd4db3db96afbeaad301d21f13";
      sha256 = "0hs829x3vxv12y78hz5g4a5qpw05xf42dk0hxxk3ind77mnl1ir1";
    };
    dependencies = [];

  };

  ctrlp-cmatcher = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ctrlp-cmatcher-2015-10-15";
    src = fetchgit {
      url = "https://github.com/JazzCore/ctrlp-cmatcher";
      rev = "6c36334f106b6fd981d23e724e9a618734cab43a";
      sha256 = "1573kd6xf3n8sxlz2j4zadai4rnc7k3s9c54648yfzickwn57d8q";
    };
    dependencies = [];
    buildInputs = [ python ];
    buildPhase = ''
      patchShebangs .
      ./install.sh
    '';
  };

  julia-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "julia-vim-2018-07-01";
    src = fetchgit {
      url = "https://github.com/JuliaEditorSupport/julia-vim";
      rev = "c49d4d39fa7f54387ec20b8bbf006700b1e01fe2";
      sha256 = "14wib4768vi7681iclihlj94dlqq1apkynma8n7p9nh3jfzd4d06";
    };
    dependencies = [];

  };

  zeavim-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "zeavim-vim-2018-03-22";
    src = fetchgit {
      url = "https://github.com/KabbAmine/zeavim.vim";
      rev = "6db8d84528d66ce6638db03c2864abfa8afa02aa";
      sha256 = "1xw8d3ap6n31rh0a4413784sx4ki7wcz8qlwm2vf9in475vvznxj";
    };
    dependencies = [];

  };

  vim-nix = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-nix-2018-07-01";
    src = fetchgit {
      url = "https://github.com/LnL7/vim-nix";
      rev = "7d71026ba7c2d0a4bdb915e884c4ac8dbdc45bf0";
      sha256 = "084vs1p0qpkc4cx049v3mkyylj1n1yvd45i1sc9qafgp4x5va457";
    };
    dependencies = [];

  };

  vim-addon-actions = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-actions-2018-01-18";
    src = fetchgit {
      url = "https://github.com/MarcWeber/vim-addon-actions";
      rev = "540cae09832ba6abf9fc63c55781bf86584c33ac";
      sha256 = "011w5k09i01r9x64j20qj0f7d057m9wki2m8l2wds47l57hr3vz6";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };

  vim-addon-async = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-async-2017-03-20";
    src = fetchgit {
      url = "https://github.com/MarcWeber/vim-addon-async";
      rev = "eca316a4480f68c2cb62128f3187dc7b2002afde";
      sha256 = "1lk8ma51dd0syi73vq5r4qk9cpy6cq3llizvh94hmxblfjpvrs7q";
    };
    dependencies = ["vim-addon-signs"];

  };

  vim-addon-background-cmd = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-background-cmd-2015-12-11";
    src = fetchgit {
      url = "https://github.com/MarcWeber/vim-addon-background-cmd";
      rev = "abf2abf339652d2bc79da81f9d131edfe2755f5a";
      sha256 = "0csy68x686l3x5ancidxb5b6prg9k7ikybqzq3klx0gs5rmksfy4";
    };
    dependencies = ["vim-addon-mw-utils"];

  };

  vim-addon-commenting = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-commenting-2013-06-10";
    src = fetchgit {
      url = "https://github.com/MarcWeber/vim-addon-commenting";
      rev = "b7cf748ac1c9bf555cbd347589e3b7196030d20b";
      sha256 = "0alak8h33vada2ckb0v06y82qlib5mhyc2yswlv1rqh8ypzhq3mc";
    };
    dependencies = [];

  };

  vim-addon-completion = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-completion-2015-02-10";
    src = fetchgit {
      url = "https://github.com/MarcWeber/vim-addon-completion";
      rev = "021c449a5ce1ce4ac0af5955e05b0279c1cc0e75";
      sha256 = "1ld059y2qwlc5bdfjm2p314s1qh31lxs54g944pw49r46s5nlslr";
    };
    dependencies = ["tlib"];

  };

  vim-addon-errorformats = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-errorformats-2014-11-05";
    src = fetchgit {
      url = "https://github.com/MarcWeber/vim-addon-errorformats";
      rev = "dcbb203ad5f56e47e75fdee35bc92e2ba69e1d28";
      sha256 = "159zqm69fxbxcv3b2y99g57bf20qrzsijcvb5rzy2njxah3049m1";
    };
    dependencies = [];

  };

  vim-addon-goto-thing-at-cursor = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-goto-thing-at-cursor-2012-01-11";
    src = fetchgit {
      url = "https://github.com/MarcWeber/vim-addon-goto-thing-at-cursor";
      rev = "f052e094bdb351829bf72ae3435af9042e09a6e4";
      sha256 = "1ksm2b0j80zn8sz2y227bpcx4jsv76lwgr2gpgy2drlyqhn2vlv0";
    };
    dependencies = ["tlib"];

  };

  vim-addon-local-vimrc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-local-vimrc-2015-03-19";
    src = fetchgit {
      url = "https://github.com/MarcWeber/vim-addon-local-vimrc";
      rev = "6a27f95b35befa70cd0d049329cd0920566c764b";
      sha256 = "0n8lwl1gyak149p7jpgm0qbmfj8hcg8hirx3dxdhizw0yc47ws7h";
    };
    dependencies = [];

  };

  vim-addon-manager = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-manager-2017-05-07";
    src = fetchgit {
      url = "https://github.com/MarcWeber/vim-addon-manager";
      rev = "2434225ae48e608c2b6ac86c8da1c62209da746f";
      sha256 = "1fczkd05gir994614qmgscx131isr71bn0rwa6n3vgdbnhasz6bb";
    };
    dependencies = [];
    buildInputs = stdenv.lib.optional stdenv.isDarwin Cocoa;
  };

  vim-addon-mru = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-mru-2013-08-08";
    src = fetchgit {
      url = "https://github.com/MarcWeber/vim-addon-mru";
      rev = "e41e39bd9d1bf78ccfd8d5e1bc05ae5e1026c2bb";
      sha256 = "0q6rxr9nrp63kidr3m3c2z5sda4g813pzshg0scxkjr8dxwhzdqm";
    };
    dependencies = ["vim-addon-other" "vim-addon-mw-utils"];

  };

  vim-addon-mw-utils = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-mw-utils-2018-03-09";
    src = fetchgit {
      url = "https://github.com/MarcWeber/vim-addon-mw-utils";
      rev = "295862ba6be47ec3b11b6c85c10d982ffd9bc0b2";
      sha256 = "0ylvhmx0cnj2x38plwqlq4pqyqyxxhf4s08hknnl7qhrr5kd533f";
    };
    dependencies = [];

  };

  vim-addon-nix = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-nix-2017-09-11";
    src = fetchgit {
      url = "https://github.com/MarcWeber/vim-addon-nix";
      rev = "3001a9db5f816dd7af11384f15415bddd146ef86";
      sha256 = "195z2yz09wirpqjpsha8x7qcr9is1q8qph4j0svws6qbqrkh8ryy";
    };
    dependencies = ["vim-addon-completion" "vim-addon-goto-thing-at-cursor" "vim-addon-errorformats" "vim-addon-actions" "vim-addon-mw-utils" "tlib"];

  };

  vim-addon-other = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-other-2014-07-15";
    src = fetchgit {
      url = "https://github.com/MarcWeber/vim-addon-other";
      rev = "f78720c9cb5bf871cabb13c7cbf94378dbf0163b";
      sha256 = "0cjz7mlyfkkncas4ss7rwxb0q38ls1qw1p15hac1imscscsvyjc6";
    };
    dependencies = ["vim-addon-actions" "vim-addon-mw-utils"];

  };

  vim-addon-php-manual = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-php-manual-2015-01-01";
    src = fetchgit {
      url = "https://github.com/MarcWeber/vim-addon-php-manual";
      rev = "5f9810dd1f6e9f36a45f637ae6260ccff09256ff";
      sha256 = "1kc67f12wccqdza069b75lpcbqp4kv4r23i4mfz0ihwif5mfnhir";
    };
    dependencies = [];

  };

  vim-addon-signs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-signs-2013-04-19";
    src = fetchgit {
      url = "https://github.com/MarcWeber/vim-addon-signs";
      rev = "17a49f293d18174ff09d1bfff5ba86e8eee8e8ae";
      sha256 = "0i4gfp30hmw1vqjl6zxjrgkca3ikdkcnjmma2mncjmcr6f59kjzy";
    };
    dependencies = [];

  };

  vim-addon-sql = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-sql-2017-02-11";
    src = fetchgit {
      url = "https://github.com/MarcWeber/vim-addon-sql";
      rev = "048a139af36829fce670c8ff80d3aad927557ee6";
      sha256 = "0ihm157sby6csdwsnw2gwh3jmm3prm1mxwgkx2hsfwlmpb1vwwm3";
    };
    dependencies = ["vim-addon-completion" "vim-addon-background-cmd" "tlib"];

  };

  vim-addon-syntax-checker = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-syntax-checker-2017-06-26";
    src = fetchgit {
      url = "https://github.com/MarcWeber/vim-addon-syntax-checker";
      rev = "739e5719b77c6aea3299c27fc1f4238ac54a8344";
      sha256 = "1rcn1ps06156nyglvxg6m7pn3vhvmnv5ad6kidp59hggyr5332i9";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };

  vim-addon-toggle-buffer = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-toggle-buffer-2012-01-13";
    src = fetchgit {
      url = "https://github.com/MarcWeber/vim-addon-toggle-buffer";
      rev = "a1b38b9c5709cba666ed2d84ef06548f675c6b0b";
      sha256 = "1xq38kfdm36c34ln66znw841q797w5gm8bpq1x64bsf2h6n3ml03";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };

  vim-addon-xdebug = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-xdebug-2014-08-29";
    src = fetchgit {
      url = "https://github.com/MarcWeber/vim-addon-xdebug";
      rev = "45f26407305b4ce6f8f5f37d2b5e6e4354104172";
      sha256 = "1i64ppdfp2qqq7vw1jf160mj4ikc04v39iazdab83xmiqjsh8ixw";
    };
    dependencies = ["WebAPI" "vim-addon-mw-utils" "vim-addon-signs" "vim-addon-async"];

  };

  tsuquyomi = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tsuquyomi-2018-07-04";
    src = fetchgit {
      url = "https://github.com/Quramy/tsuquyomi";
      rev = "9247e0f1ad0e1ae7d350ad5b27ef92269955cc65";
      sha256 = "09mihjiqg407n14gb4kr60fnyp3rpi18fr9nhnpg1ym2ly0nsa1l";
    };
    dependencies = [];

  };

  clang_complete = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "clang_complete-2018-01-18";
    src = fetchgit {
      url = "https://github.com/Rip-Rip/clang_complete";
      rev = "0918788ea0b9dc4c753ffd162c95f890ae57a275";
      sha256 = "19hf7xrx1lsvn5rhwmc0qc1qzpb365j1d0jzvihd99p0zkgzgj1p";
    };
    dependencies = [];
    # In addition to the arguments you pass to your compiler, you also need to
    # specify the path of the C++ std header (if you are using C++).
    # These usually implicitly set by cc-wrapper around clang (pkgs/build-support/cc-wrapper).
    # The linked ruby code shows generates the required '.clang_complete' for cmake based projects
    # https://gist.github.com/Mic92/135e83803ed29162817fce4098dec144
    # as an alternative you can execute the following command:
    # $ eval echo $(nix-instantiate --eval --expr 'with (import <nixpkgs>) {}; clang.default_cxx_stdlib_compile')
    preFixup = ''
      substituteInPlace "$out"/share/vim-plugins/clang_complete/plugin/clang_complete.vim \
        --replace "let g:clang_library_path = '' + "''" + ''" "let g:clang_library_path='${llvmPackages.clang.cc}/lib/libclang.so'"
    '';
  };

  riv-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "riv-vim-2018-06-21";
    src = fetchgit {
      url = "https://github.com/Rykka/riv.vim";
      rev = "fb6d6f8c9d85128fd69c74f11bb7413addc002e8";
      sha256 = "1mjp90lz6jf3w9j4h1sidz7kfxhi9hk27pdnvb0hrvxw0q3bj9ch";
    };
    dependencies = [];

  };

  ultisnips = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ultisnips-2018-04-30";
    src = fetchgit {
      url = "https://github.com/SirVer/ultisnips";
      rev = "6fdc3647f72e0a1f321ea6bd092ecd01f7c187ba";
      sha256 = "1zp3xcmxk6cn38zmxxy5s2wnw9djskwkmspq2s9vqliyhprf9sy3";
    };
    dependencies = [];

  };

  vim-hoogle = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-hoogle-2018-03-04";
    src = fetchgit {
      url = "https://github.com/Twinside/vim-hoogle";
      rev = "871d104c92e33cb238506f2805f1652561978cc8";
      sha256 = "17qvi57g72ijgk7nczczli3kcphvdf625fzqbqcmqpsawgvfd07n";
    };
    dependencies = [];

  };

  vim-gitgutter = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-gitgutter-2018-07-06";
    src = fetchgit {
      url = "https://github.com/airblade/vim-gitgutter";
      rev = "6076c9678643a8b2fc9973f16ec9efcd5dbe1aca";
      sha256 = "1dyrll5rm61qdmzkym67hfyw80qnw10s1qrz9ryw3zvh1s2ad43l";
    };
    dependencies = [];

  };

  Spacegray-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Spacegray-vim-2018-06-20";
    src = fetchgit {
      url = "https://github.com/ajh17/Spacegray.vim";
      rev = "f9e5205319cbb5c598bbf02b16c3d05277817f81";
      sha256 = "1s32zf75ybqs9jjjvqk5z4x9a6lr43gjbwlgw8k01qf4lsxkzkn9";
    };
    dependencies = [];

  };

  nerdtree-git-plugin = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "nerdtree-git-plugin-2017-03-12";
    src = fetchgit {
      url = "https://github.com/albfan/nerdtree-git-plugin";
      rev = "d79a5d5a1b3bc5fab3ba94db44a8b2e5a211d61d";
      sha256 = "0i77wijbr021zfv096ja15f5l52phvsd5gziqn1m3k60qkmb9gkj";
    };
    dependencies = [];

  };

  vim-colors-solarized = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-colors-solarized-2011-05-09";
    src = fetchgit {
      url = "https://github.com/altercation/vim-colors-solarized";
      rev = "528a59f26d12278698bb946f8fb82a63711eec21";
      sha256 = "05d3lmd1shyagvr3jygqghxd3k8a4vp32723fvxdm57fdrlyzcm1";
    };
    dependencies = [];

  };

  vim-closetag = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-closetag-2018-05-15";
    src = fetchgit {
      url = "https://github.com/alvan/vim-closetag";
      rev = "17367f433e095a66a8a885ab628033ce2a635aa1";
      sha256 = "11qkk1vsihw2sv1vdn94xjwm2p5hvisjv5h1arpdyxpnz45rs6vh";
    };
    dependencies = [];

  };

  ctrlp-z = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ctrlp-z-2015-10-17";
    src = fetchgit {
      url = "https://github.com/amiorin/ctrlp-z";
      rev = "d1a69ec623ce24b9a30fc8fe3cd468c322b03026";
      sha256 = "16nsj1g8lqmyizlb5ijwhf4dsmh0xv1kwqq6jxvhaf55vfga82yl";
    };
    dependencies = [];

  };

  vim-logreview = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-logreview-2017-07-08";
    src = fetchgit {
      url = "https://github.com/andreshazard/vim-logreview";
      rev = "b7b66ab338e904127d796af49235b8c29742f18f";
      sha256 = "09lyymq0f3ybqdzhbpia7b0wcjbcyg5nkqd72qk8jkvc42da2af3";
    };
    dependencies = [];

  };

  peskcolor-vim-git = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "peskcolor-vim-git-2016-06-11";
    src = fetchgit {
      url = "https://github.com/andsild/peskcolor.vim.git";
      rev = "cba4fc739bbebacd503158f6509d9c226651f363";
      sha256 = "15hw3casr5y3ckgcn6aq8vhk6g2hym41w51nvgf34hbj9fx1nvkq";
    };
    dependencies = [];

  };

  flake8-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "flake8-vim-2017-02-17";
    src = fetchgit {
      url = "https://github.com/andviro/flake8-vim";
      rev = "01c4af4c68f33b2b3785314bfbf5b3d8d1451795";
      sha256 = "14rv0p1vx4njlplkc72gz7r8sy9vc6n8x9l00zc777x5zzrhgz3g";
    };
    dependencies = [];

  };

  vim-css-color = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-css-color-2018-03-06";
    src = fetchgit {
      url = "https://github.com/ap/vim-css-color";
      rev = "afaacf50e65b7d30b170e70ee13c1518dce1e032";
      sha256 = "1ck8qv3wfmc7rdddzd7zh2dsnb0rx69grmc0laz7n1358xg0i4vx";
    };
    dependencies = [];

  };

  vim-bazel = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-bazel-2018-01-10";
    src = fetchgit {
      url = "https://github.com/bazelbuild/vim-bazel";
      rev = "ecafb17d5d1d3756e5ac0bd9f4812a450b8c91a3";
      sha256 = "0ixhx9ssfygjy2v2ss02w28rcjxnvhj0caffj32cv3snwnpcz6fy";
    };
    dependencies = ["maktaba"];

  };

  clighter8 = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "clighter8-2018-07-25";
    src = fetchgit {
      url = "https://github.com/bbchung/clighter8";
      rev = "839993b60dc4a19a58e4c7e7db1df04d911bb181";
      sha256 = "01r92idbym2p1hiqszrprrl1hrqzz2yhzv8n08m8gycd7m227cwg";
    };
    dependencies = [];
    preFixup = ''
      sed "/^let g:clighter8_libclang_path/s|')$|${llvmPackages.clang.cc}/lib/libclang.so')|" \
        -i "$out"/share/vim-plugins/clighter8/plugin/clighter8.vim
    '';
  };

  neomake = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neomake-2018-07-23";
    src = fetchgit {
      url = "https://github.com/benekastah/neomake";
      rev = "b24cac5f6aa1d8f8e8bcfae52ed255f277f4f163";
      sha256 = "00hmbip0r3l0h6fk0bxs9rqbfj0vn246804s2s7shdjsvn6a3pa0";
    };
    dependencies = [];

  };

  vim-hdevtools = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-hdevtools-2017-03-11";
    src = fetchgit {
      url = "https://github.com/bitc/vim-hdevtools";
      rev = "4ffdace7002915cb10d663a2c56386286c5b8e37";
      sha256 = "0s7qd72962sc56j8xzpzikjs9k5s89d5p0j541abl8zm0mavmyka";
    };
    dependencies = [];

  };

  vim-trailing-whitespace = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-trailing-whitespace-2017-09-22";
    src = fetchgit {
      url = "https://github.com/bronson/vim-trailing-whitespace";
      rev = "4c596548216b7c19971f8fc94e38ef1a2b55fee6";
      sha256 = "0f1cpnp1nxb4i5hgymjn2yn3k1jwkqmlgw1g02sq270lavp2dzs9";
    };
    dependencies = [];

  };

  vim-toml = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-toml-2018-06-15";
    src = fetchgit {
      url = "https://github.com/cespare/vim-toml";
      rev = "85ba8277a6e331a56fce920d62bfdacce5bc5a80";
      sha256 = "0nnm4ja5j9gcsl9cv7ra30slrlpjpy4dsl0ykg0yhdq1vbby3m6n";
    };
    dependencies = [];

  };

  denite-extra = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "denite-extra-2018-07-19";
    src = fetchgit {
      url = "https://github.com/chemzqm/denite-extra";
      rev = "10836562703ebfe6552204e63b9b4293236d6d0f";
      sha256 = "1jq6wv6vhjpkd9xy8i6rjd0l69djvxg8395ylclr2dv21carx5z6";
    };
    dependencies = [];

  };

  denite-git = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "denite-git-2018-07-19";
    src = fetchgit {
      url = "https://github.com/chemzqm/denite-git";
      rev = "edd2c202e05c3f84e31b94a841fef236b923d559";
      sha256 = "0x8nf4x49859lgyi83vhqvpdhb1mxv55a9l8vbdflfagagj0gnzd";
    };
    dependencies = [];

  };

  concealedyank-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "concealedyank-vim-2013-03-24";
    src = fetchgit {
      url = "https://github.com/chikatoike/concealedyank.vim";
      rev = "e7e65a395e0e6a266f3a808bc07441aa7d03ebbd";
      sha256 = "0z7i8dmwfjh6mcrmgrxv3j86ic867617fas9mv4gqsrhhvrrkzsb";
    };
    dependencies = [];

  };

  sourcemap-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "sourcemap-vim-2012-09-19";
    src = fetchgit {
      url = "https://github.com/chikatoike/sourcemap.vim";
      rev = "0dd82d40faea2fdb0771067f46c01deb41610ba1";
      sha256 = "1gcgnynallz420911fdfm0ccbv3zs78p69nnh2ls1r4vlfp7g350";
    };
    dependencies = [];

  };

  CheckAttach = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "CheckAttach-2018-07-18";
    src = fetchgit {
      url = "https://github.com/chrisbra/CheckAttach";
      rev = "0f1f2e78071d7f805a0a679955cb4486f692b753";
      sha256 = "11skk275ijq8hwpp0zxsdgr08brq08v1syvyawck8vzrnqrq71sc";
    };
    dependencies = [];

  };

  csv-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "csv-vim-2018-06-24";
    src = fetchgit {
      url = "https://github.com/chrisbra/csv.vim";
      rev = "918be3bd15920fd9bc79fca5e6870b8055742a1a";
      sha256 = "01fhw55s5q23ny3n7ldg53n3raysr2wnnkpfybbba2wv55w5vpdy";
    };
    dependencies = [];

  };

  sparkup = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "sparkup-2012-06-10";
    src = fetchgit {
      url = "https://github.com/chrisgeo/sparkup";
      rev = "6fbfceef890e705c47b42b27be743ffed6f9296e";
      sha256 = "17jgpvl879ik53rr3razfnbpfx63mzpp1rlvxxjsvvrk4g45dssm";
    };
    dependencies = [];

  };

  base16-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "base16-vim-2018-05-24";
    src = fetchgit {
      url = "https://github.com/chriskempson/base16-vim";
      rev = "fcce6bce6a2f4b14eea7ea388031c0aa65e4b67d";
      sha256 = "0wi8k80v2brmxqbkk0lrvl4v2sslkjfwpvflm55b3n0ii8qy39nk";
    };
    dependencies = [];

  };

  vim-sort-motion = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-sort-motion-2018-07-15";
    src = fetchgit {
      url = "https://github.com/christoomey/vim-sort-motion";
      rev = "49dfcabeee2bf3a85a6cc0774b35f687b6c9d0e5";
      sha256 = "02v12iqy3gjhvh5aza6b6b3pfv2qkyyw83bxqjgbjj002f71ydkb";
    };
    dependencies = [];

  };

  vim-tmux-navigator = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-tmux-navigator-2018-07-13";
    src = fetchgit {
      url = "https://github.com/christoomey/vim-tmux-navigator";
      rev = "18b775fbccde5ff02e516c014290650bb40e257d";
      sha256 = "09v8amrdk8h4hsr9va8v9wdgzvj89z04y4j71l94rd7r6smxinbj";
    };
    dependencies = [];

  };

  spacevim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "spacevim-2018-03-29";
    src = fetchgit {
      url = "https://github.com/ctjhoa/spacevim";
      rev = "30142a518ba77feb22791b5cb2387d88b70c58f2";
      sha256 = "0m389cnpg17ca8s7vb9yrs40sxb56zg32lcpilnd63zfi7awgscg";
    };
    dependencies = [];

  };

  ctrlp-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ctrlp-vim-2018-06-28";
    src = fetchgit {
      url = "https://github.com/ctrlpvim/ctrlp.vim";
      rev = "43cc73b8e7d4ab45f17118573eb81fd45704b989";
      sha256 = "16jn9n6vavwiwh6l2av2i3livan72saaz0d0v8vmznrrs2ngi1gk";
    };
    dependencies = [];

  };

  vim2hs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim2hs-2014-04-16";
    src = fetchgit {
      url = "https://github.com/dag/vim2hs";
      rev = "f2afd55704bfe0a2d66e6b270d247e9b8a7b1664";
      sha256 = "18lqrl3hqb6cmizc04bbnsh8j0g761w2q8wascbzzfw80dmxy36b";
    };
    dependencies = [];

  };

  quickfixstatus = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "quickfixstatus-2011-09-02";
    src = fetchgit {
      url = "https://github.com/dannyob/quickfixstatus";
      rev = "fd3875b914fc51bbefefa8c4995588c088163053";
      sha256 = "16vxhvyxq51y7wnx0c1fmdi2yb6kfr1pxijq65gxj8qwvbak2s3v";
    };
    dependencies = [];

  };

  agda-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "agda-vim-2018-05-23";
    src = fetchgit {
      url = "https://github.com/derekelkins/agda-vim";
      rev = "24169e70c1dbd784349b1551b6a3753680d9bb87";
      sha256 = "1bn2g89dvwccfl4ki07jb8iydb3d0s4rm7z5gv5q1bv3lccndax6";
    };
    dependencies = [];

  };

  vim-scala = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-scala-2017-11-10";
    src = fetchgit {
      url = "https://github.com/derekwyatt/vim-scala";
      rev = "0b909e24f31d94552eafae610da0f31040c08f2b";
      sha256 = "1lqqapimgjr7k4imr26ap0lgx6k4qjl5gmgb1knvh5kz100bsjl5";
    };
    dependencies = [];

  };

  vim-table-mode = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-table-mode-2018-05-16";
    src = fetchgit {
      url = "https://github.com/dhruvasagar/vim-table-mode";
      rev = "5483e163bd0a67e729e0e8436315f33f9e126baf";
      sha256 = "0mmpa7zhrj8mqf4931ldf6n9jlpfxc4kg8xdhqlp7srlnq4h8siw";
    };
    dependencies = [];

  };

  vim-jade = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-jade-2017-04-07";
    src = fetchgit {
      url = "https://github.com/digitaltoad/vim-jade";
      rev = "ddc5592f8c36bf4bd915c16b38b8c76292c2b975";
      sha256 = "069pha18g1nlzg44k742vjxm4zwjd1qjzhfllkr35qaiflvjm84y";
    };
    dependencies = [];

  };

  pony-vim-syntax = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "pony-vim-syntax-2017-09-26";
    src = fetchgit {
      url = "https://github.com/dleonard0/pony-vim-syntax";
      rev = "caa34b3d7a15d9bfbfbb2f5944c85eb1eddcfafc";
      sha256 = "0r2lv99hkm95dv8wy9rkrkcwz5wkmwggfwi5vakgw497l3a9jskr";
    };
    dependencies = [];

  };

  vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-2018-07-23";
    src = fetchgit {
      url = "https://github.com/dracula/vim";
      rev = "d329d61c1752807059aef388c4e9629296760a35";
      sha256 = "06f5jg194w1fzh4bfj7cbibn94a1zx987f8iiaylkqzj3h0fn3fm";
    };
    dependencies = [];

  };

  xptemplate = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "xptemplate-2017-12-06";
    src = fetchgit {
      url = "https://github.com/drmingdrmer/xptemplate";
      rev = "74aac3aebaf9c67c12c21d6b25295b9bec9c93b3";
      sha256 = "01yvas50hg7iwwrdh61407mc477byviccksgi0fkaz89p78bbd1p";
    };
    dependencies = [];

  };

  ghcmod-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ghcmod-vim-2016-06-19";
    src = fetchgit {
      url = "https://github.com/eagletmt/ghcmod-vim";
      rev = "1d192d13d68ab59f9f46497a0909bf24a7b7dfff";
      sha256 = "0bzahgzagnf0a9zv86jhdf8nc3p0yfz9izv5n3lc8gc12cp47d0a";
    };
    dependencies = [];

  };

  neco-ghc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neco-ghc-2018-05-13";
    src = fetchgit {
      url = "https://github.com/eagletmt/neco-ghc";
      rev = "682869aca5dd0bde71a09ba952acb59c543adf7d";
      sha256 = "1v7ibi4fp99s4lswz3v0gf4i0h5i5gpj05xpsf4cixwj2zgh206h";
    };
    dependencies = [];

  };

  editorconfig-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "editorconfig-vim-2018-07-25";
    src = fetchgit {
      url = "https://github.com/editorconfig/editorconfig-vim";
      rev = "2c3e5323609d97ad7bda6fc22ae1f7746caab3d4";
      sha256 = "0a1nszrhxh9ixp5n47w89ijkvjk3rf29ypiz5blf4pnja39r336x";
    };
    dependencies = [];

  };

  vim-cute-python-git = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-cute-python-git-2016-04-04";
    src = fetchgit {
      url = "https://github.com/ehamberg/vim-cute-python.git";
      rev = "d7a6163f794500447242df2bedbe20bd751b92da";
      sha256 = "1jrfd6z84cdzn3yxdfp0xfxygscq7s8kbzxk37hf9cf5pl9ln0qf";
    };
    dependencies = [];

  };

  acp = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "acp-2013-02-05";
    src = fetchgit {
      url = "https://github.com/eikenb/acp";
      rev = "5c627cec37d0d3b1670cb250d84e176e8b0c644e";
      sha256 = "0h7s4nvxin7m2caka7g1hhlxj1bbiwsvw8s2lqwlh7nq43v23ghg";
    };
    dependencies = [];

  };

  vim-elixir = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-elixir-2018-05-25";
    src = fetchgit {
      url = "https://github.com/elixir-lang/vim-elixir";
      rev = "b916c00a7cdb6099dbebb6096eab55794751e2b3";
      sha256 = "1scg80j7kjjqfcswddwsig166zmipa9q6rm0kh8779i7qflgg4g0";
    };
    dependencies = [];

  };

  elm-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "elm-vim-2018-06-18";
    src = fetchgit {
      url = "https://github.com/elmcast/elm-vim";
      rev = "e51e2e43ad617c26205a84453481d3ac152c8fec";
      sha256 = "09bgfjnpa1s25x5wnxry9lmsly92s0mazn1sl0vg2wfgphf67m6b";
    };
    dependencies = [];

  };

  vim-json = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-json-2018-01-10";
    src = fetchgit {
      url = "https://github.com/elzr/vim-json";
      rev = "3727f089410e23ae113be6222e8a08dd2613ecf2";
      sha256 = "1c19pqrys45pzflj5jyrm4q6hcvs977lv6qsfvbnk7nm4skxrqp1";
    };
    dependencies = [];

  };

  vim-localvimrc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-localvimrc-2018-07-23";
    src = fetchgit {
      url = "https://github.com/embear/vim-localvimrc";
      rev = "a3cb22a68625e022df1da402361801cc817bcec5";
      sha256 = "0n3fl4wh5bhppxwkpd69jmnck2js08dgzfxcpfqrvx22zr22m8kc";
    };
    dependencies = [];

  };

  vim-haskellConcealPlus = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-haskellConcealPlus-2016-05-13";
    src = fetchgit {
      url = "https://github.com/enomsg/vim-haskellConcealPlus";
      rev = "81dfb51ff8e471fb1f30659a10daaf1bdd65fb03";
      sha256 = "0vm76gxw62lkyxccrlnn8sblfl3d51svwfra9wfixq4h51jdggyr";
    };
    dependencies = [];

  };

  ensime-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ensime-vim-2018-04-21";
    src = fetchgit {
      url = "https://github.com/ensime/ensime-vim";
      rev = "634cce6eae10a31cd6eec259890bdcda326ee3c2";
      sha256 = "03sr53680kcwxaa5xbqzdfbsgday3bkzja33wym49w9gjmlaa320";
    };
    dependencies = ["vimproc" "vimshell" "self" "forms"];
    pythonDependencies = with pythonPackages; [ sexpdata websocket_client ];
  };

  supertab = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "supertab-2017-11-14";
    src = fetchgit {
      url = "https://github.com/ervandew/supertab";
      rev = "40fe711e088e2ab346738233dd5adbb1be355172";
      sha256 = "0l5labq68kyprv63k1q35hz5ly0dd06mf2z202mccnix4mlxf0db";
    };
    dependencies = [];

  };

  YUNOcommit-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "YUNOcommit-vim-2014-11-26";
    src = fetchgit {
      url = "https://github.com/esneider/YUNOcommit.vim";
      rev = "981082055a73ef076d7e27477874d2303153a448";
      sha256 = "0mjc7fn405vcx1n7vadl98p5wgm6jxrlbdbkqgjq8f1m1ir81zab";
    };
    dependencies = [];

  };

  vim-go = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-go-2018-07-22";
    src = fetchgit {
      url = "https://github.com/fatih/vim-go";
      rev = "5e26ce6bfa9400f645aaa5898f802f46275b9585";
      sha256 = "1m380n3sdsqydn5dbjj1cafslbr1426ihz1a7rxr980z5jd43hj1";
    };
    dependencies = [];

  };

  vim-isort = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-isort-2017-03-12";
    src = fetchgit {
      url = "https://github.com/fisadev/vim-isort";
      rev = "65bd9fecd5412c8c127de86f8dcf6cfe4dd70fda";
      sha256 = "0d9r2p557czrqhn3z35jsrzp3iw6n0vjhxcgkk6l0y79ni3dar1m";
    };
    dependencies = [];
    postPatch = ''
      substituteInPlace ftplugin/python_vimisort.vim \
          --replace 'import vim' 'import vim; import sys; sys.path.append("${pythonPackages.isort}/${python.sitePackages}")'
    '';
  };

  vim-colorschemes = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-colorschemes-2017-08-22";
    src = fetchgit {
      url = "https://github.com/flazz/vim-colorschemes";
      rev = "eab315701f4627967fd62582eefc4e37a3745786";
      sha256 = "12jfqfs6lqd6jijxrdx3k76bzxrh9517zwczb73qjaqbg286fh5k";
    };
    dependencies = [];

  };

  floobits-neovim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "floobits-neovim-2017-08-02";
    src = fetchgit {
      url = "https://github.com/floobits/floobits-neovim";
      rev = "9ccd5a8d5d28261b9686717d61a32b756f38f189";
      sha256 = "02njg49qz9bfzggpn7z5c7w1wa1k5hxly66904wizl601fa6c664";
    };
    dependencies = [];

  };

  psc-ide-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "psc-ide-vim-2018-03-11";
    src = fetchgit {
      url = "https://github.com/frigoeu/psc-ide-vim";
      rev = "6d4a3cc27e9782b703f6dd61ef5fdf27054bac0f";
      sha256 = "19w0cvrka3klxbh9z1yq873v92rhmxdj68bdnqxzwybf24hgsk9g";
    };
    dependencies = [];

  };

  vim-snipmate = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-snipmate-2017-04-20";
    src = fetchgit {
      url = "https://github.com/garbas/vim-snipmate";
      rev = "a9802f2351910f64b70fb10b63651e6ff6b8125e";
      sha256 = "1l7sc6lf66pkiy18aq9s3wk1dmvvvsy1063cc0bxich9xa8m34bj";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };

  vundle = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vundle-2018-02-02";
    src = fetchgit {
      url = "https://github.com/gmarik/vundle";
      rev = "9a38216a1c0c597f978d73547d37681fc689c90d";
      sha256 = "1695glma8zf2lnp0w713sdvwqagf1s127p4i60114nk6gx5g5x2c";
    };
    dependencies = [];

  };

  csapprox = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "csapprox-2013-07-26";
    src = fetchgit {
      url = "https://github.com/godlygeek/csapprox";
      rev = "7981dac51d8b6776985aa08cb7b5ee98ea7f2ddd";
      sha256 = "08g4x6nnd6hkgm2daa5ihhz75pcdx3jzzv8rfjls80qajlhx5rf6";
    };
    dependencies = [];

  };

  tabular = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tabular-2016-05-04";
    src = fetchgit {
      url = "https://github.com/godlygeek/tabular";
      rev = "00e1e7fcdbc6d753e0bc8043e0d2546fa81bf367";
      sha256 = "185jpisk9hamcwb6aiavdzjdbbigzdra8f4mgs98r9cm9j448xkz";
    };
    dependencies = [];

  };

  vim-codefmt = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-codefmt-2018-06-06";
    src = fetchgit {
      url = "https://github.com/google/vim-codefmt";
      rev = "78f646545c4e1254fc413242e5c204a2dc79665d";
      sha256 = "0ysnjsc7nybm374k039655y1wijkh8p2m0hsfxf9cxf79yjinyql";
    };
    dependencies = ["maktaba"];

  };

  vim-jsonnet = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-jsonnet-2018-04-10";
    src = fetchgit {
      url = "https://github.com/google/vim-jsonnet";
      rev = "1425166887329363381194adc457b02b663b1354";
      sha256 = "0kkpvp1r06l3glhgw4wv3ihqisjhs5m0x7mxgy388hy4r73fx08j";
    };
    dependencies = [];

  };

  vim-maktaba = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-maktaba-2018-05-06";
    src = fetchgit {
      url = "https://github.com/google/vim-maktaba";
      rev = "ffdb1a5a9921f7fd722c84d0f60e166f9916b67d";
      sha256 = "1cmhgd9xvx09l6ypks09gxqs1vad1bddinf4cx2jmd516bv8qss3";
    };
    dependencies = [];

  };

  gitv = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "gitv-2018-06-10";
    src = fetchgit {
      url = "https://github.com/gregsexton/gitv";
      rev = "41e4ffdbdb02374412d03c5680906ebee84dd5a2";
      sha256 = "1wfp3kkcvrccq0dqplg3ymyz9vdwn1c5wabh6mwfzbs2zx01vwcn";
    };
    dependencies = ["fugitive"];

  };

  xterm-color-table-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "xterm-color-table-vim-2013-12-31";
    src = fetchgit {
      url = "https://github.com/guns/xterm-color-table.vim";
      rev = "9754e857e5f4fe1f8727106dcc682d21c29a51e4";
      sha256 = "08a1d9428xwrjp40qgi34cb5fwgc239qf3agxl32k7bqbn08pq19";
    };
    dependencies = [];

  };

  vim-jsdoc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-jsdoc-2018-05-05";
    src = fetchgit {
      url = "https://github.com/heavenshell/vim-jsdoc";
      rev = "5ef086789f5ac431d1d5aab53e771f00f1c25503";
      sha256 = "0f0dbcvbmha2nfadvf27crxkkxc1ps1inss5n66vy1p5bffv0bpm";
    };
    dependencies = [];

  };

  vim-leader-guide = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-leader-guide-2017-03-18";
    src = fetchgit {
      url = "https://github.com/hecal3/vim-leader-guide";
      rev = "6ac8c663e65c9c0ded70417b84f66ee59457893e";
      sha256 = "1hqha3ig40ls15bnb10xpbl91swn0gxqnhmz5frkvvdzj4wq55fw";
    };
    dependencies = [];

  };

  vim-snippets = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-snippets-2018-07-19";
    src = fetchgit {
      url = "https://github.com/honza/vim-snippets";
      rev = "1143432afdb3a97b606b081700eead5b4f499d4d";
      sha256 = "1z0pgpsv8y1zhxlm6w76wgd4wx378wbq44mvgxxfxi0mfvb6vywf";
    };
    dependencies = [];

  };

  idris-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "idris-vim-2017-12-04";
    src = fetchgit {
      url = "https://github.com/idris-hackers/idris-vim";
      rev = "091ed6b267749927777423160eeab520109dd9c1";
      sha256 = "1zibar2vxcmai0k37ricwnimfdv1adxfbbvz871rc4l6h3q85if1";
    };
    dependencies = [];

  };

  vim-SyntaxRange = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-SyntaxRange-2018-03-09";
    src = fetchgit {
      url = "https://github.com/inkarkat/vim-SyntaxRange";
      rev = "dc33d8f84ebbf4c9fa03ce00b8adeb83e05249d3";
      sha256 = "0nf0hkgl5fm0laxb5253br894259kz33zyiwxzrry6w3108alasr";
    };
    dependencies = [];

  };

  vim-extradite = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-extradite-2015-09-22";
    src = fetchgit {
      url = "https://github.com/int3/vim-extradite";
      rev = "52326f6d333cdbb9e9c6d6772af87f4f39c00526";
      sha256 = "0c89i0spvdm9vi65q15qcmsfmwa9rds2wmaq1kf6s7q7ywvs6w8i";
    };
    dependencies = [];

  };

  calendar-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "calendar-vim-2018-07-04";
    src = fetchgit {
      url = "https://github.com/itchyny/calendar.vim";
      rev = "f27fcf52c8a516f55ede5cff468f0a3e4014ae1b";
      sha256 = "07gg83bgj9c43jn66zlvyc1avqjyidb9cjwdv1ln3965zkl47b5r";
    };
    dependencies = [];

  };

  lightline-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "lightline-vim-2018-07-05";
    src = fetchgit {
      url = "https://github.com/itchyny/lightline.vim";
      rev = "0532dff598abca9975d3f80128eaadadbf1d91d4";
      sha256 = "1wvhl2wc2p4vqi7zzj7wdyq0cnbfq8s7g5ifcchj8f5s8c4h4lfc";
    };
    dependencies = [];

  };

  thumbnail-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "thumbnail-vim-2017-04-24";
    src = fetchgit {
      url = "https://github.com/itchyny/thumbnail.vim";
      rev = "71cb5d48e59fc77149c1d1036ecd9e39f0b46a00";
      sha256 = "0b25n28ri6n5rrvgfynv8rm5pzzxpnrnj1l3647pf2fjxd2z2rv5";
    };
    dependencies = [];

  };

  vim-cursorword = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-cursorword-2017-10-19";
    src = fetchgit {
      url = "https://github.com/itchyny/vim-cursorword";
      rev = "4878d6185b99131c5f610cc6ad0e223439ac4601";
      sha256 = "170nf0w7i5k3cr72dkvraq2p0lzsvb3cmdvslyz7cmxnz611n6bf";
    };
    dependencies = [];

  };

  vim-gitbranch = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-gitbranch-2017-05-28";
    src = fetchgit {
      url = "https://github.com/itchyny/vim-gitbranch";
      rev = "8118dc1cdd387bd609852be4bf350360ce881193";
      sha256 = "01gvd96mnzfc5s0951zzq122birg5svnximkldgb9kv5bmsnmh3j";
    };
    dependencies = [];

  };

  vim-ipython = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-ipython-2015-06-23";
    src = fetchgit {
      url = "https://github.com/ivanov/vim-ipython";
      rev = "42499f094b805b90b683afa5009cee99abd0bb75";
      sha256 = "10wpfvfs8yv1bvzra4d5zy5glp62gbalpayxx7mkalhr2ccppy3x";
    };
    dependencies = [];

  };

  tender-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tender-vim-2017-03-14";
    src = fetchgit {
      url = "https://github.com/jacoborus/tender.vim";
      rev = "6b0497a59233b3e67fb528a498069eb1d24743f9";
      sha256 = "1iqijk7xq0g6p3j8jgzgrhqizw87fnfryx73iaqqx5iyq1k8i9mn";
    };
    dependencies = [];

  };

  vim-test-git = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-test-git-2018-07-10";
    src = fetchgit {
      url = "https://github.com/janko-m/vim-test.git";
      rev = "e24477e81e91fe90c5d914849848027cb09a7c86";
      sha256 = "1kkfzs0bmbg4kjips1jylrsd5rqd39ab2x2z1a64pjkx1fvl703b";
    };
    dependencies = [];

  };

  vim-hier = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-hier-2011-08-27";
    src = fetchgit {
      url = "https://github.com/jceb/vim-hier";
      rev = "0b8c365263551a67404ebd7e528c55e17c1d3de7";
      sha256 = "118pd9sx1bl9vfr89xrf536hfx4l162a43a1qpwpkqxzb9a3ca7n";
    };
    dependencies = [];
    buildInputs = [ vim ];
  };

  vim-orgmode = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-orgmode-2018-07-25";
    src = fetchgit {
      url = "https://github.com/jceb/vim-orgmode";
      rev = "35e94218c12a0c063b4b3a9b48e7867578e1e13c";
      sha256 = "0j6zfqqysnky4z54413l87q7wxbskg0zb221zbz48ry4l1anilhx";
    };
    dependencies = [];

  };

  vim-buffergator = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-buffergator-2018-05-02";
    src = fetchgit {
      url = "https://github.com/jeetsukumaran/vim-buffergator";
      rev = "947b60dca4d4fc6a041a6ec84b17ca6736d1b916";
      sha256 = "1b6sw5858h3v7p46v1fiy06jnfwiwqsfqwhr46ia12d0rfdm538c";
    };
    dependencies = [];

  };

  tslime-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tslime-vim-2018-07-23";
    src = fetchgit {
      url = "https://github.com/jgdavey/tslime.vim";
      rev = "28e9eba642a791c6a6b044433dce8e5451b26fb0";
      sha256 = "1y5xikryv6851d0rjk9c64agawshp5208mwym6ma9ngs7s3s1l4x";
    };
    dependencies = [];

  };

  vim-docbk = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-docbk-2015-04-01";
    src = fetchgit {
      url = "https://github.com/jhradilek/vim-docbk";
      rev = "6ac0346ce96dbefe982b9e765a81c072997f2e9e";
      sha256 = "1jnx39m152hf9j620ygagaydg6h8m8gxkr1fmxj6kgqf71jr0n9d";
    };
    dependencies = [];

  };

  auto-pairs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "auto-pairs-2017-07-03";
    src = fetchgit {
      url = "https://github.com/jiangmiao/auto-pairs";
      rev = "f0019fc6423e7ce7bbd01d196a7e027077687fda";
      sha256 = "1kzrdq3adwxwm3fw65g05ww9405lwqi368win5kayamyj9i0z7r6";
    };
    dependencies = [];

  };

  vim-nerdtree-tabs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-nerdtree-tabs-2018-05-05";
    src = fetchgit {
      url = "https://github.com/jistr/vim-nerdtree-tabs";
      rev = "5fc6c6857028a07e8fe50f0adef28fb20218776b";
      sha256 = "051m4jb8jcc9rbafp995hmf4q6zn07bwh7anra6k1cr14i9lasaa";
    };
    dependencies = [];

  };

  zenburn = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "zenburn-2018-04-29";
    src = fetchgit {
      url = "https://github.com/jnurmine/zenburn";
      rev = "2cacfcb222d9db34a8d1a13bb8bb814f039b98cd";
      sha256 = "0m5d5sjckirfpdhg9sf1nl5xywvzdx6y04r13m47jlavf79hhimi";
    };
    dependencies = [];

  };

  vim-colorstepper = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-colorstepper-2016-01-28";
    src = fetchgit {
      url = "https://github.com/jonbri/vim-colorstepper";
      rev = "f23ba0d995d41508a2dc9471cf31d3d01a4b5f05";
      sha256 = "05ykxn0gmh8liz0zv5hb8df1ajggxp88izq3825m0yb3ma3k1jqs";
    };
    dependencies = [];

  };

  vim-xdebug = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-xdebug-2012-08-15";
    src = fetchgit {
      url = "https://github.com/joonty/vim-xdebug";
      rev = "a4980fa65f7f159780593ee37c178281691ba2c4";
      sha256 = "1qh18r0sm4gh95sjbi2hnflvxdl4gk00jyy3n7z4i1gnx9ihxjqw";
    };
    dependencies = [];
    postInstall = false;
  };

  fzf-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "fzf-vim-2018-07-22";
    src = fetchgit {
      url = "https://github.com/junegunn/fzf.vim";
      rev = "6ce58caad320be3cf9ff5d275191f88524edf326";
      sha256 = "02s6ky1mnb18iy91p6syy3qnp55zwg2d52ybm6cic2gwvj1az1sf";
    };
    dependencies = [];

  };

  goyo-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "goyo-vim-2017-06-01";
    src = fetchgit {
      url = "https://github.com/junegunn/goyo.vim";
      rev = "5b8bd0378758c1d9550d8429bef24b3d6d78b592";
      sha256 = "0jh2gyf6v1vl12hygzwylzsj1ivx7r6xrd75k2wfsy91b2pm9srj";
    };
    dependencies = [];

  };

  limelight-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "limelight-vim-2016-06-24";
    src = fetchgit {
      url = "https://github.com/junegunn/limelight.vim";
      rev = "106fb5749d227a0de72e36068ed72798c6fd48e6";
      sha256 = "0fp4yp50n5v5zx3a7afh9wip4nwcfhmdgdzwpnl79jvild1z9fgh";
    };
    dependencies = [];

  };

  vim-easy-align = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-easy-align-2017-06-03";
    src = fetchgit {
      url = "https://github.com/junegunn/vim-easy-align";
      rev = "1cd724dc239c3a0f7a12e0fac85945cc3dbe07b0";
      sha256 = "0bqk1sdqamfgagh31a60c7gvvsvjpg1xys7ivqh62iqlny5i9774";
    };
    dependencies = [];

  };

  vim-dashboard = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-dashboard-2017-08-08";
    src = fetchgit {
      url = "https://github.com/junegunn/vim-github-dashboard";
      rev = "054d7c69d9882a6ffccedd6e43623e184958d3b6";
      sha256 = "1ns6dd8719hqrkqnxd52ssi7gxjxni7w4l1ih7ag72d62qzw0p8y";
    };
    dependencies = [];

  };

  vim-peekaboo = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-peekaboo-2017-03-20";
    src = fetchgit {
      url = "https://github.com/junegunn/vim-peekaboo";
      rev = "a7c940b15b008afdcea096d3fc4d25e3e431eb49";
      sha256 = "1rc4hr6vwj2mmrgz8lifxf9rvcw1rb5dahq649yn8ccw03x8zn6m";
    };
    dependencies = [];

  };

  vim-eighties = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-eighties-2016-12-15";
    src = fetchgit {
      url = "https://github.com/justincampbell/vim-eighties";
      rev = "1a6ea42ead1e31524ec94cfefb6afc1d8dacd170";
      sha256 = "1yh1kny28c7f5qm52y7xd5aj4mycksfb0x1zvcb37c73ycdxc1v2";
    };
    dependencies = [];

  };

  vim-niceblock = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-niceblock-2018-01-30";
    src = fetchgit {
      url = "https://github.com/kana/vim-niceblock";
      rev = "178629a8b81da2fa614bd6c19e7797e325ee9153";
      sha256 = "1bz8qjnwk3gz9h0194g3qqga91i4k78r9s1xymn2fv35llrfsdx0";
    };
    dependencies = [];

  };

  vim-operator-replace = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-operator-replace-2015-02-25";
    src = fetchgit {
      url = "https://github.com/kana/vim-operator-replace";
      rev = "1345a556a321a092716e149d4765a5e17c0e9f0f";
      sha256 = "07cibp61zwbzpjfxqdc77fzrgnz8jhimmdhhyjr0lvgrjgvsnv6q";
    };
    dependencies = [];

  };

  vim-operator-user = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-operator-user-2015-02-17";
    src = fetchgit {
      url = "https://github.com/kana/vim-operator-user";
      rev = "c3dfd41c1ed516b4b901c97562e644de62c367aa";
      sha256 = "16y2fyrmwg4vkcl85i8xg8s6m39ca2jvgi9qm36b3vzbnkcifafb";
    };
    dependencies = [];

  };

  vim-tabpagecd = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-tabpagecd-2013-11-29";
    src = fetchgit {
      url = "https://github.com/kana/vim-tabpagecd";
      rev = "8b71a03a037608fa5918f5096812577cec6355e4";
      sha256 = "1mr6s2hvsf2a2nkjjvq78c9isfxk2k1ih890w740srbq6ssj0npm";
    };
    dependencies = [];

  };

  vim-coffee-script = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-coffee-script-2018-02-27";
    src = fetchgit {
      url = "https://github.com/kchmck/vim-coffee-script";
      rev = "9e3b4de2a476caeb6ff21b5da20966d7c67a98bb";
      sha256 = "1yzhyi12r508r2yjkzbcnddv3q4whjf3kchp23xs0snhwd9b981x";
    };
    dependencies = [];

  };

  swift-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "swift-vim-2018-07-21";
    src = fetchgit {
      url = "https://github.com/keith/swift.vim";
      rev = "40d53b215fd455e4b7fd413eaf14d1a028a504ab";
      sha256 = "1lbxi0n5x5xnskfylbcpazch00lxbfhnc2h70x196yc4fhwz9153";
    };
    dependencies = [];

  };

  rainbow_parentheses-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "rainbow_parentheses-vim-2013-03-04";
    src = fetchgit {
      url = "https://github.com/kien/rainbow_parentheses.vim";
      rev = "eb8baa5428bde10ecc1cb14eed1d6e16f5f24695";
      sha256 = "1qw84imlhq4654mxazj7j3sp5g1j3yjxi496i08iix06dm15m5s7";
    };
    dependencies = [];

  };

  fastfold = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "fastfold-2018-06-02";
    src = fetchgit {
      url = "https://github.com/konfekt/fastfold";
      rev = "4150ebdc6e226e8797d42dcabb7463952de9dc30";
      sha256 = "0mdb77np2vf564q18fvj1klr99pwrx2sw0jhxify9g7i0177qs4r";
    };
    dependencies = [];

  };

  vim-signature = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-signature-2018-07-06";
    src = fetchgit {
      url = "https://github.com/kshenoy/vim-signature";
      rev = "6bc3dd1294a22e897f0dcf8dd72b85f350e306bc";
      sha256 = "08m5dg77yavria7n7iajkj4kqaw848763680003j2gbrjlhpprpm";
    };
    dependencies = [];

  };

  vim-gista = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-gista-2017-02-20";
    src = fetchgit {
      url = "https://github.com/lambdalisue/vim-gista";
      rev = "b6cd41d0eb480cd79e84f3da3703613d0cf94a6c";
      sha256 = "0bkzbppd3jdci4yvifb4sh05q20qn8cr3j9kqhxyc703s0l0lk2s";
    };
    dependencies = [];

  };

  latex-box = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "latex-box-2015-06-01";
    src = fetchgit {
      url = "https://github.com/latex-box-team/latex-box";
      rev = "3c2901e12cb78bfb2be58ba4c62a488612550fe1";
      sha256 = "1z4mdy47cpwcdhvy8mr72vhlybxn1y59yd3ixf6ids1bzpkrd7zl";
    };
    dependencies = [];

  };

  typescript-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "typescript-vim-2018-03-08";
    src = fetchgit {
      url = "https://github.com/leafgarland/typescript-vim";
      rev = "e25636b44211a4be7b089bfed7cf09aa7dd086f5";
      sha256 = "1i422j4za5xwcv3zz7cjw523nnh5q652c04phqp681lgdmgqszh4";
    };
    dependencies = [];

  };

  vim-ledger = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-ledger-2017-12-12";
    src = fetchgit {
      url = "https://github.com/ledger/vim-ledger";
      rev = "6eb3bb21aa979cc295d0480b2179938c12b33d0d";
      sha256 = "0rbwyaanvl2bqk8xm4kq8fkv8y92lpf9xx5n8gw54iij7xxhnj01";
    };
    dependencies = [];

  };

  vim-jinja = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-jinja-2016-11-16";
    src = fetchgit {
      url = "https://github.com/lepture/vim-jinja";
      rev = "8d330a7aaf0763d080dc82204b4aaba6ac0605c6";
      sha256 = "1n62ga02rcj7jjgzvwr46pckj59dc1zqahjgampjcwdd8vf4mg3q";
    };
    dependencies = [];

  };

  vimtex = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimtex-2018-07-25";
    src = fetchgit {
      url = "https://github.com/lervag/vimtex";
      rev = "5c5cd72b680bca8c3b5b45ee790f3f6f5890e77c";
      sha256 = "1pahrkf536ay56jdiqdda1bq0q5d788bvf099r0wvxwgqk77hr6n";
    };
    dependencies = [];

  };

  cosco-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "cosco-vim-2018-02-15";
    src = fetchgit {
      url = "https://github.com/lfilho/cosco.vim";
      rev = "434dc68b93b8f42babe1887a269145ce39c97edf";
      sha256 = "1ng91nkkd9rgyihp4dvzrj7drm31d9r2vx4id1n8v6gc1rx3qasv";
    };
    dependencies = [];

  };

  vim-easymotion = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-easymotion-2018-06-05";
    src = fetchgit {
      url = "https://github.com/lokaltog/vim-easymotion";
      rev = "1a0244c90c3ff46219cf9597bb13662be4232407";
      sha256 = "1gsfn4fgivfg821wmnrdzpmqdimjkvkqi3gwr0nwf07ygjbr2csy";
    };
    dependencies = [];

  };

  vim-lawrencium = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-lawrencium-2017-01-10";
    src = fetchgit {
      url = "https://github.com/ludovicchabant/vim-lawrencium";
      rev = "88077183e1f5a9a1f741aeab7a1374cfed9e917f";
      sha256 = "0z31v93wjycq4lqvbl1jzxi7i5i1vl919m4dyyzphybcqrjjpnab";
    };
    dependencies = [];

  };

  rainbow = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "rainbow-2018-06-19";
    src = fetchgit {
      url = "https://github.com/luochen1990/rainbow";
      rev = "549724c2123c5a06834676963be0d76d5c37abc1";
      sha256 = "0hh0w337qw5yk9flk4iz4vfpa4q13blvyv10hgbfrqy72s30gpdf";
    };
    dependencies = [];

  };

  vim-xkbswitch = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-xkbswitch-2017-03-27";
    src = fetchgit {
      url = "https://github.com/lyokha/vim-xkbswitch";
      rev = "a85ebddb9038e6b05138c48868a319a9e13d1868";
      sha256 = "0v0wckkvsj3pd3a5lj35dqwlvgr1kfz0x6rpnx28mzrcg05p19fr";
    };
    dependencies = [];
    patchPhase = ''
      substituteInPlace plugin/xkbswitch.vim \
              --replace /usr/local/lib/libxkbswitch.so ${xkb_switch}/lib/libxkbswitch.so
    '';
    buildInputs = [ xkb_switch ];
  };

  vim-highlightedyank = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-highlightedyank-2018-06-01";
    src = fetchgit {
      url = "https://github.com/machakann/vim-highlightedyank";
      rev = "eafae05916e670da8bc99e44b1534cd8c7f87c7a";
      sha256 = "1z6xjb9244fgnhmw21m7y3bd9vs9gvxbb9ig73iwy0ny886hjlnk";
    };
    dependencies = [];

  };

  tagbar = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tagbar-2017-12-17";
    src = fetchgit {
      url = "https://github.com/majutsushi/tagbar";
      rev = "387bbadda98e1376ff3871aa461b1f0abd4ece70";
      sha256 = "0srmslg0v1a7zhzz0wgzgv7jyr0j3q9m766qzb7zimkkb32fcbx9";
    };
    dependencies = [];

  };

  vim-jsbeautify = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-jsbeautify-2018-01-31";
    src = fetchgit {
      url = "https://github.com/maksimr/vim-jsbeautify";
      rev = "7a55bffa7d87e4f1ed11650e56a1361779b39624";
      sha256 = "01jvc3nkvmhw9n7m9x96ax1ndzw78ryjmgrvkqb7gja1xb8i8jqq";
    };
    dependencies = [];

  };

  Jenkinsfile-vim-syntax = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Jenkinsfile-vim-syntax-2018-04-03";
    src = fetchgit {
      url = "https://github.com/martinda/Jenkinsfile-vim-syntax";
      rev = "45418b171e06f63e0814cac6a656832384708aba";
      sha256 = "0vfx22fzp0894lclmbsp6l8apvw0znd3cbah8r7r5la9qzyiwi4p";
    };
    dependencies = [];

  };

  gist-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "gist-vim-2016-10-10";
    src = fetchgit {
      url = "https://github.com/mattn/gist-vim";
      rev = "f0d63579eab7548cf12f979dc52ef5a370ecbe63";
      sha256 = "06nix49j4inxy3rkcv32f4ka89g4crqwfqnrm3b76iwwky8m2p17";
    };
    dependencies = [];

  };

  webapi-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "webapi-vim-2018-03-14";
    src = fetchgit {
      url = "https://github.com/mattn/webapi-vim";
      rev = "252250381a9509257bfb06b9f95441e41e3e23b5";
      sha256 = "0g37d1i6rxsj6f31g9jy2bhr8ng3jwmnvqqcmw19vbql4v56zq6a";
    };
    dependencies = [];

  };

  undotree = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "undotree-2018-07-02";
    src = fetchgit {
      url = "https://github.com/mbbill/undotree";
      rev = "a80159c9f5c238575b63984b8bc610bc5de6b233";
      sha256 = "10l091qbigcj053l65bs3cdnysasl7f2qdbsk8bk6k0xj7rrpgzl";
    };
    dependencies = [];

  };

  forms = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "forms-2012-11-28";
    src = fetchgit {
      url = "https://github.com/megaannum/forms";
      rev = "b601e03fe0a3b8a43766231f4a6217e4492b4f75";
      sha256 = "19kp1i5c6jmnpbsap9giayqbzlv7vh02mp4mjvicqj9n0nfyay74";
    };
    dependencies = ["self"];

  };

  self = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "self-2014-05-28";
    src = fetchgit {
      url = "https://github.com/megaannum/self";
      rev = "2ed666b547eddee6ae1fcc63babca4ba0b66a59f";
      sha256 = "1gcwn6i5i3msg7hrlzsnv1bs6pm4jz9cff8ppaz2xdj8xv9qy6fn";
    };
    dependencies = [];

  };

  robotframework-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "robotframework-vim-2017-04-14";
    src = fetchgit {
      url = "https://github.com/mfukar/robotframework-vim";
      rev = "75d5b371a4da2a090a2872d55bd0dead013f334e";
      sha256 = "091ac5rq6f1a7j2q3dy9rc00vckv21m4wd29ijj63jannr02v5ad";
    };
    dependencies = [];

  };

  vim-grepper-git = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-grepper-git-2018-04-24";
    src = fetchgit {
      url = "https://github.com/mhinz/vim-grepper.git";
      rev = "04d659c9e0a57e0c3e989069601d2a98df0386c4";
      sha256 = "16k5ahcn9i4wvlhw16j0gfgxw0clry72l78lk28qmx9p2gh1ka3g";
    };
    dependencies = [];

  };

  vim-signify = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-signify-2018-07-25";
    src = fetchgit {
      url = "https://github.com/mhinz/vim-signify";
      rev = "a9fc705b9bdffaac46f13e47d6565c904102dedc";
      sha256 = "0hk24anfhh1v62zn03cbqrf8c260q6g5cka8dpq8c5943v6kln59";
    };
    dependencies = [];

  };

  vim-startify = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-startify-2018-07-21";
    src = fetchgit {
      url = "https://github.com/mhinz/vim-startify";
      rev = "8cde338d1f35057fd64146090c960a55b953dcd9";
      sha256 = "01aali5s946589cxy8k5qb0qzhxwlgwv4grri3x60h2520fc1z29";
    };
    dependencies = [];

  };

  vim-indent-object = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-indent-object-2018-04-08";
    src = fetchgit {
      url = "https://github.com/michaeljsmith/vim-indent-object";
      rev = "5c5b24c959478929b54a9e831a8e2e651a465965";
      sha256 = "1kmwnz0jxjkvfzy06r7r73pcxfcyjp8p8m2d6qrhjfvzidgfhw19";
    };
    dependencies = [];

  };

  ack-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ack-vim-2018-02-28";
    src = fetchgit {
      url = "https://github.com/mileszs/ack.vim";
      rev = "36e40f9ec91bdbf6f1adf408522a73a6925c3042";
      sha256 = "0yppr89hd1jyp0pj56hxdjbn32sr7pj3mihd18wxispvl5dqd6fm";
    };
    dependencies = [];

  };

  vim-yapf = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-yapf-2018-06-05";
    src = fetchgit {
      url = "https://github.com/mindriot101/vim-yapf";
      rev = "cae79733a1a39732c5305d4a89cd093d17cb917d";
      sha256 = "16bmzvzks6kbqm6dk908k23b9wj7qf3x8bz3kikrzj27s0p7s9cc";
    };
    dependencies = [];
    buildPhase = ''
      substituteInPlace ftplugin/python_yapf.vim \
        --replace '"yapf"' '"${python3Packages.yapf}/bin/yapf"'
    '';
  };

  lushtags = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "lushtags-2017-04-19";
    src = fetchgit {
      url = "https://github.com/mkasa/lushtags";
      rev = "fd7fa5a0162d9aa159559880d5ba4731e180eeaf";
      sha256 = "1si5n07k4r8kji4whglav9q59ksv6bi5v58xbpc2l5bavlk8kn6n";
    };
    dependencies = [];

  };

  gruvbox = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "gruvbox-2018-02-25";
    src = fetchgit {
      url = "https://github.com/morhetz/gruvbox";
      rev = "cb4e7a5643f7d2dd40e694bcbd28c4b89b185e86";
      sha256 = "12qkq1x96bm1cmqfg6sb8jxpl2b6gwvhc5qn3gva6vl4nx3ianqi";
    };
    dependencies = [];

  };

  hlint-refactor-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "hlint-refactor-vim-2015-12-05";
    src = fetchgit {
      url = "https://github.com/mpickering/hlint-refactor-vim";
      rev = "fffb044ecef854a82c5c2efda252e09044ba03e0";
      sha256 = "0z8d31arfy9aidg1dwj5msnnx799d9r7njkgh51z695w6ayxn6p8";
    };
    dependencies = [];

  };

  vim-indent-guides = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-indent-guides-2018-05-14";
    src = fetchgit {
      url = "https://github.com/nathanaelkane/vim-indent-guides";
      rev = "54d889a63716ee2f1818aa2ec5082db47147147b";
      sha256 = "0ahlbjv2ibhhnf9zqn85b2sh3wf9l0kmg2qmavz3z5fmf8sqljj2";
    };
    dependencies = [];

  };

  vim-stylish-haskell = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-stylish-haskell-2015-05-10";
    src = fetchgit {
      url = "https://github.com/nbouscal/vim-stylish-haskell";
      rev = "c664376ba814de3f87cb7641f90b2c6a9dd53671";
      sha256 = "1xm5ark2mwphznv3xsyzgcldnr52i5jzk1pfqdh0080j07aama8j";
    };
    dependencies = [];

  };

  vim-easygit = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-easygit-2018-07-08";
    src = fetchgit {
      url = "https://github.com/neoclide/vim-easygit";
      rev = "9770370a35838f70eda91d0c3006d0563ccc8d2a";
      sha256 = "1a42s0nymakz20rjrpwmiqpnlndrkdakzbm53aclzcs61i9zq2k8";
    };
    dependencies = [];

  };

  haskell-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "haskell-vim-2018-05-22";
    src = fetchgit {
      url = "https://github.com/neovimhaskell/haskell-vim";
      rev = "b1ac46807835423c4a4dd063df6d5b613d89c731";
      sha256 = "1vqj3r2v8skffywwgv4093ww7fm540437j5qz7n8q8787bs5w0br";
    };
    dependencies = [];

  };

  cpsm = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "cpsm-2018-02-01";
    src = fetchgit {
      url = "https://github.com/nixprime/cpsm";
      rev = "8a4a0a05162762b857b656d51b59a5bf01850877";
      sha256 = "0v44gf9ygrqc6rpfpiq329jija4icy0iy240yk30c0r04mjahc0b";
    };
    dependencies = [];
    buildInputs = [
      python3
      stdenv
      cmake
      boost
      icu
      ncurses
    ];
    buildPhase = ''
      patchShebangs .
      export PY3=ON
      ./install.sh
    '';
  };

  vim-iced-coffee-script = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-iced-coffee-script-2013-12-27";
    src = fetchgit {
      url = "https://github.com/noc7c9/vim-iced-coffee-script";
      rev = "e42e0775fa4b1f8840c55cd36ac3d1cedbc1dea2";
      sha256 = "14yfirny359rlrr082il2ys3hxiyrbbk794rdxrs2lasjy8rb1f7";
    };
    dependencies = [];

  };

  shabadou-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "shabadou-vim-2016-07-19";
    src = fetchgit {
      url = "https://github.com/osyo-manga/shabadou.vim";
      rev = "7d4bfed1ea8985ae125df3d1403cc19e252443e1";
      sha256 = "1kvik1yf7yjg9jdmdw38yhkksxg0n3nry02banwik7wgjnpvg870";
    };
    dependencies = [];

  };

  vim-textobj-multiblock = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-textobj-multiblock-2014-06-02";
    src = fetchgit {
      url = "https://github.com/osyo-manga/vim-textobj-multiblock";
      rev = "670a5ba57d73fcd793f480e262617c6eb0103355";
      sha256 = "1s71hdr73cl8yg9mrdflvzrdccpiv7qrlainai7gqw30r1hfhfzf";
    };
    dependencies = [];

  };

  vim-watchdogs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-watchdogs-2017-12-03";
    src = fetchgit {
      url = "https://github.com/osyo-manga/vim-watchdogs";
      rev = "a6415c2d928af8c1aacdbce9b1ed8d315891eb03";
      sha256 = "0n6aqsgn0q1qgpj4yznqwbsbbk2a077gnjlq86ii3jhkzh5fzcff";
    };
    dependencies = [];

  };

  vim-javascript = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-javascript-2018-07-14";
    src = fetchgit {
      url = "https://github.com/pangloss/vim-javascript";
      rev = "39e332a3c36c0115e1eab85c34cf121b7585869d";
      sha256 = "04ycwh298i213zw0zvj99igfmxf36swycryapsgp9jrh9jjd9hmw";
    };
    dependencies = [];

  };

  vim-markdown = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-markdown-2018-06-05";
    src = fetchgit {
      url = "https://github.com/plasticboy/vim-markdown";
      rev = "6d2cb3c06cd546fd4bee4136679db3a3d5de97fa";
      sha256 = "17izjzgpwpl6i1vvz2hcd7ympgxyjmsb0k62rhvl15jmx06c3ysz";
    };
    dependencies = [];

  };

  python-mode = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "python-mode-2018-07-23";
    src = fetchgit {
      url = "https://github.com/python-mode/python-mode";
      rev = "d241974f40e8d206f9970e51fb0069951862ba35";
      sha256 = "1cjhlbk71785zy0g0lf2bmsdsnvqwx03v8lxq7i7j2qazalszxci";
    };
    dependencies = [];

  };

  vim-racer = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-racer-2018-05-13";
    src = fetchgit {
      url = "https://github.com/racer-rust/vim-racer";
      rev = "cd663ddacc89fb3cbbb9649f7cd36528960b1fe9";
      sha256 = "1k75ypgiy13l28mndi6p95lc818k04imlm7xk0y9sck8bsny1vhi";
    };
    dependencies = [];

  };

  awesome-vim-colorschemes = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "awesome-vim-colorschemes-2018-01-20";
    src = fetchgit {
      url = "https://github.com/rafi/awesome-vim-colorschemes";
      rev = "8d2b6657bdbe4f7253e320c741bc4c1fc2f2f41d";
      sha256 = "1wfm6rsmyqldxwcz0ic4rq7kf00fgsx00rg42cl9yya35nqiri2z";
    };
    dependencies = [];

  };

  purescript-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "purescript-vim-2018-07-05";
    src = fetchgit {
      url = "https://github.com/raichoo/purescript-vim";
      rev = "ab8547cef5827f046d43ba57203acb6692b7ef06";
      sha256 = "1pp7h77qqhgshf2x3hh73gnb4ya8jamqm75spbnn95piznd03k33";
    };
    dependencies = [];

  };

  vim-pencil = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-pencil-2017-06-14";
    src = fetchgit {
      url = "https://github.com/reedes/vim-pencil";
      rev = "2dcd974b7255e4af83cf79a208f04a3489065e22";
      sha256 = "0swc6sszj1f4h5hgi7z7j1xw54d69mg7f18rk2kf5y453qwg4jc0";
    };
    dependencies = [];

  };

  vim-wordy = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-wordy-2018-03-10";
    src = fetchgit {
      url = "https://github.com/reedes/vim-wordy";
      rev = "14b9dbf76a82e29273a74768573900361200467f";
      sha256 = "0qx3ngw4k7bgzmxpv1x4lkq3njm3zcb1j5ph6fx26wgagxhiaqhk";
    };
    dependencies = [];

  };

  committia-vim-git = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "committia-vim-git-2018-07-14";
    src = fetchgit {
      url = "https://github.com/rhysd/committia.vim.git";
      rev = "6aa77b9161e75828d0be2ba40ed420cbf7a55279";
      sha256 = "0sr7wzccj805fnc48qgcshp8rypz3vb8507pkc1r3pn7wbxqkni1";
    };
    dependencies = [];

  };

  vim-grammarous = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-grammarous-2018-06-22";
    src = fetchgit {
      url = "https://github.com/rhysd/vim-grammarous";
      rev = "0d8a0272389a32bd49e74bb00527c02f9aca19a8";
      sha256 = "0ji18hjhp1gx147z682b4xy1w02kqcr8rb5frccyqn4kdpqhqvbk";
    };
    dependencies = [];
    # use `:GrammarousCheck` to initialize checking
    # In neovim, you also want to use set
    #   let g:grammarous#show_first_error = 1
    # see https://github.com/rhysd/vim-grammarous/issues/39
    patches = [
      (substituteAll {
        src = ./patches/vim-grammarous/set_default_languagetool.patch;
        inherit languagetool;
      })
    ];
  };

  vim-operator-surround = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-operator-surround-2017-12-23";
    src = fetchgit {
      url = "https://github.com/rhysd/vim-operator-surround";
      rev = "001c0da077b5b38a723151b19760d220e02363db";
      sha256 = "0c6w6id57faw6sjf5wvw9qp2a4i7xj65q0c4hjs0spgzycv2wpkh";
    };
    dependencies = [];

  };

  vim-puppet = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-puppet-2018-04-12";
    src = fetchgit {
      url = "https://github.com/rodjek/vim-puppet";
      rev = "dc1f681045c4d8bd126063ce000f7cc7b2f95097";
      sha256 = "18z2d2wpn5c3g857wprmdwp5pdb719dciyy0682hqpw8lfjn6zhv";
    };
    dependencies = [];

  };

  nvim-cm-racer = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "nvim-cm-racer-2017-07-27";
    src = fetchgit {
      url = "https://github.com/roxma/nvim-cm-racer";
      rev = "2a8a4a49fa58c5dac9e0bed9511f6928930cacd2";
      sha256 = "1yljxwypgn91084yyicbc2qprn31ld7s4drvnddzczyhzq5m2gpx";
    };
    dependencies = [];

  };

  nvim-completion-manager = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "nvim-completion-manager-2018-04-18";
    src = fetchgit {
      url = "https://github.com/roxma/nvim-completion-manager";
      rev = "3ef5ade36e7321aace4e9e22da216202bdcd65f1";
      sha256 = "0vfcnvdcxhs3in4pwcqjb5h3ns7ik53n4xb1h9r94w1gfw00lh1l";
    };
    dependencies = [];

  };

  rust-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "rust-vim-2018-07-17";
    src = fetchgit {
      url = "https://github.com/rust-lang/rust.vim";
      rev = "2fa74427456a68e9e90f542567f851df50d48a8c";
      sha256 = "0vqvw5czwy3v99dv5gbgy8ljg31qhsnhqjfl0a4dfij6p66xyi46";
    };
    dependencies = [];

  };

  vim-devicons = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-devicons-2018-06-21";
    src = fetchgit {
      url = "https://github.com/ryanoasis/vim-devicons";
      rev = "ea5bbf0e2a960965accfa50a516773406a5b6b26";
      sha256 = "1v365j4an1k82gk06ikgqy2dw0ir80kj0svs1fymgklc117xgqsg";
    };
    dependencies = [];

  };

  neoformat = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neoformat-2018-07-16";
    src = fetchgit {
      url = "https://github.com/sbdchd/neoformat";
      rev = "f20e73193f2260d4437d160759d6b623a74a5a35";
      sha256 = "0460v5h82zsgslqxkiwf2qbkah15hf3p33ddvcipfqg0rnrbwynp";
    };
    dependencies = [];

  };

  nerdcommenter = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "nerdcommenter-2018-06-21";
    src = fetchgit {
      url = "https://github.com/scrooloose/nerdcommenter";
      rev = "9a32fd2534427f7a1dcfe22e9c0ea6b67b6dbe78";
      sha256 = "0s862kzhvv9qpr7gxd3h52hczjvm55zyff5qn0z5095072pr3wjx";
    };
    dependencies = [];

  };

  nerdtree = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "nerdtree-2018-06-15";
    src = fetchgit {
      url = "https://github.com/scrooloose/nerdtree";
      rev = "d6032c876c6d6932ab7f07e262a16c9a85a31d5b";
      sha256 = "0s7z60rcdkziqqjc45adfqykpznv7aagfyfi5ybsxi5w4b8f2b9s";
    };
    dependencies = [];

  };

  syntastic = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "syntastic-2018-07-16";
    src = fetchgit {
      url = "https://github.com/scrooloose/syntastic";
      rev = "0dde090ed41b383b1fa56f8db49d89e0735b1ca9";
      sha256 = "027g3wmfdrhb65krlfs89xk3imbm2mgzb2ddv7xwrhch736nvb2q";
    };
    dependencies = [];

  };

  deoplete-rust = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "deoplete-rust-2017-07-18";
    src = fetchgit {
      url = "https://github.com/sebastianmarkow/deoplete-rust";
      rev = "0a86e502113910c33448b337c4d50cabea120d25";
      sha256 = "0wsck83jns40ny3740vwjhc8g5bh6zl71hkirbjxy6n4xgixa54h";
    };
    dependencies = [];

  };

  vim-polyglot = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-polyglot-2018-07-08";
    src = fetchgit {
      url = "https://github.com/sheerun/vim-polyglot";
      rev = "055f7710b65dfa2df52fc0b5be2486ae36ac5751";
      sha256 = "1q1aw0sapr2zgrxbh97g6hj22f2xym3apzfxw5xxmqzmjc0kiq4p";
    };
    dependencies = [];

  };

  context_filetype-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "context_filetype-vim-2018-04-01";
    src = fetchgit {
      url = "https://github.com/shougo/context_filetype.vim";
      rev = "9ed76080795ef76f52b8c9ae4432df7cd81abc5a";
      sha256 = "137ki4104j4ch54k9n1l1xd75vbxqssi1fdckzv8kd07m5i159i2";
    };
    dependencies = [];

  };

  denite-nvim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "denite-nvim-2018-07-22";
    src = fetchgit {
      url = "https://github.com/shougo/denite.nvim";
      rev = "93d8eb0bf21eb6db3f6a0bf6a84a98bd578176c8";
      sha256 = "0bhvg9rynqr2nkj7h2h8ws6mm1s7wmgif8avwbirq4pxby5j5f8r";
    };
    dependencies = [];

  };

  deoplete-nvim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "deoplete-nvim-2018-07-22";
    src = fetchgit {
      url = "https://github.com/shougo/deoplete.nvim";
      rev = "59fbd61d492b0a1728f34b8958d8e4dbce165c73";
      sha256 = "06x46dhyy9bix0svl2c0jxxk7rs8ahzl18yq6hmfb1j45jlv5qiz";
    };
    dependencies = [];

  };

  echodoc-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "echodoc-vim-2018-03-26";
    src = fetchgit {
      url = "https://github.com/shougo/echodoc.vim";
      rev = "f1f711bc814165cf5b09b56fd5d733917ed1c015";
      sha256 = "0l0sm862fbr8p8m4wykx1riidxgp233cq6r2zdm2l7gvmqyj3zcr";
    };
    dependencies = [];

  };

  neco-syntax = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neco-syntax-2017-10-01";
    src = fetchgit {
      url = "https://github.com/shougo/neco-syntax";
      rev = "98cba4a98a4f44dcff80216d0b4aa6f41c2ce3e3";
      sha256 = "1cjcbgx3h00g91ifgw30q5n97x4nprsr4kwirydws79fcs4vkgip";
    };
    dependencies = [];

  };

  neco-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neco-vim-2017-10-01";
    src = fetchgit {
      url = "https://github.com/shougo/neco-vim";
      rev = "f5397c5e800d65a58c56d8f1b1b92686b05f4ca9";
      sha256 = "0yb7ja6qgrazszk4i01cwjj00j9vd43zs2r11b08iy8n10jnzr73";
    };
    dependencies = [];

  };

  neocomplete-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neocomplete-vim-2018-03-28";
    src = fetchgit {
      url = "https://github.com/shougo/neocomplete.vim";
      rev = "4be617947f3fcf2d725fab20b0e12f8b46c9e2f3";
      sha256 = "00ns46gy726w74nmnzhqnyh10jnpr04453v3rclswxgcvgma82b8";
    };
    dependencies = [];

  };

  neoinclude-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neoinclude-vim-2018-05-22";
    src = fetchgit {
      url = "https://github.com/shougo/neoinclude.vim";
      rev = "2fa77b9211d3f10c29559b715b6863da67ae7d3a";
      sha256 = "0pdahb2z9q4dk67xkwvaqrlpai86slhncfb4gn88x40dlnd7rkbg";
    };
    dependencies = [];

  };

  neomru-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neomru-vim-2017-10-01";
    src = fetchgit {
      url = "https://github.com/shougo/neomru.vim";
      rev = "97540f54fa20b94daf306f0c1f3cce983bbf7a1d";
      sha256 = "15d5hmh5v3hnjnfb5736n45rh5nyq41vqjp1cz4ls2rxmmfi3xa7";
    };
    dependencies = [];

  };

  neosnippet-snippets = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neosnippet-snippets-2018-06-17";
    src = fetchgit {
      url = "https://github.com/shougo/neosnippet-snippets";
      rev = "e5946e9ec4c68965dbabfaaf2584b1c057738afd";
      sha256 = "114w2vm28075bz85867lz0rzam1m0wk7dkbkm1lm0jbknbpk606n";
    };
    dependencies = [];

  };

  neosnippet-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neosnippet-vim-2018-07-19";
    src = fetchgit {
      url = "https://github.com/shougo/neosnippet.vim";
      rev = "2959ae99f6e8f422e7d9062fd0a3cd692d2221fb";
      sha256 = "0zdyfc9lrp8g76b6qigci6dlxz0zqpqf5y9887x2zdy631dksfi4";
    };
    dependencies = [];

  };

  neoyank-vim-git = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neoyank-vim-git-2018-03-26";
    src = fetchgit {
      url = "https://github.com/shougo/neoyank.vim.git";
      rev = "ea3cd47ccb40cb2e26cb607d28475aa0fdb26fef";
      sha256 = "1zbf8062rpk56nd1zxqhwa8bdpxl9zp887l9nm4s9hc4ndsk4928";
    };
    dependencies = [];

  };

  tabpagebuffer-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tabpagebuffer-vim-2014-09-30";
    src = fetchgit {
      url = "https://github.com/shougo/tabpagebuffer.vim";
      rev = "4d95c3e6fa5ad887498f4cbe486c11e39d4a1fbc";
      sha256 = "1z6zlpzkhwy1p2pmx9qrwb91dp9v4yi8jrdvm1if2k79ij4sl08f";
    };
    dependencies = [];

  };

  unite-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "unite-vim-2018-06-17";
    src = fetchgit {
      url = "https://github.com/shougo/unite.vim";
      rev = "c175ba7df239a5971e4c189ecbc9486b160fbde2";
      sha256 = "16j5vhmqs04y5rps5g86bgpf91w067gyw9rz47hf0y0a52niy436";
    };
    dependencies = [];

  };

  vimproc-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimproc-vim-2018-01-07";
    src = fetchgit {
      url = "https://github.com/shougo/vimproc.vim";
      rev = "2300224d366642f4f8d6f88861535d4ccbe20143";
      sha256 = "0b8ljqnix8bs667bpymg3s0g5f49fnphgddl6196dj6jvdfn1xia";
    };
    dependencies = [];
    buildInputs = [ which ];

    buildPhase = ''
      substituteInPlace autoload/vimproc.vim \
        --replace vimproc_mac.so vimproc_unix.so \
        --replace vimproc_linux64.so vimproc_unix.so \
        --replace vimproc_linux32.so vimproc_unix.so
      make -f make_unix.mak
    '';
  };

  fugitive-gitlab-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "fugitive-gitlab-vim-2018-07-04";
    src = fetchgit {
      url = "https://github.com/shumphrey/fugitive-gitlab.vim";
      rev = "b8e7b6986c5d13f3e2de2163816af06f74a6f838";
      sha256 = "1lvll9hjqsm79f0ls84d8b8s12043b9p5qa4i6iwf3v1qbq7kb8d";
    };
    dependencies = [];

  };

  gundo-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "gundo-vim-2017-05-09";
    src = fetchgit {
      url = "https://github.com/sjl/gundo.vim";
      rev = "46c443ee9d5854320eb965a1fdee781ba83a070e";
      sha256 = "0adk7agzmbfv342zw6lc8jad6yjs1wap4c0ca98s0qm2bs0r1hl2";
    };
    dependencies = [];

  };

  splice-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "splice-vim-2017-09-03";
    src = fetchgit {
      url = "https://github.com/sjl/splice.vim";
      rev = "b31cb25eea8a92a037e9da9a98b2e6147294c37d";
      sha256 = "0mqnrmkyms2z5lqy90cy076x3fr9xmd63962wd8n6n6mbin97ihx";
    };
    dependencies = [];

  };

  last256 = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "last256-2017-06-11";
    src = fetchgit {
      url = "https://github.com/sk1418/last256";
      rev = "d29320c1fe715b47edaa1be068201ea5a54ab0c0";
      sha256 = "16njh0p1j166dnf92110vlrj7gmrbsfkbkd8k6s9gfqjzbgd25jv";
    };
    dependencies = [];

  };

  alchemist-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "alchemist-vim-2018-06-25";
    src = fetchgit {
      url = "https://github.com/slashmili/alchemist.vim";
      rev = "5575fc8e18695b050b1c4d51623ae37f12ff7648";
      sha256 = "0s1x0avshxfrqj9vd8bahkw10sn9hmajwch285zib9aynqp5x2ma";
    };
    dependencies = [];

  };

  vim-smalls = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-smalls-2015-05-02";
    src = fetchgit {
      url = "https://github.com/t9md/vim-smalls";
      rev = "9619eae81626bd63f88165e0520c467698264e34";
      sha256 = "0s5z3zv220cg95yky2av6w0jmpc56ysyhsx0596ksvgz5jwhpbad";
    };
    dependencies = [];

  };

  vim-hardtime = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-hardtime-2017-03-31";
    src = fetchgit {
      url = "https://github.com/takac/vim-hardtime";
      rev = "d9128568afa62947b7ac8f12c22d88e3de526a6b";
      sha256 = "097wzfh4n4fnsq2gx4hbmyr731ciky8qcai5aiyh2baybvwshmr5";
    };
    dependencies = [];

  };

  vim-expand-region = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-expand-region-2013-08-19";
    src = fetchgit {
      url = "https://github.com/terryma/vim-expand-region";
      rev = "966513543de0ddc2d673b5528a056269e7917276";
      sha256 = "0l30wjlk4vxr16f1njnvf8aw9yg9p9jisvcxbcg3znsq5q8ix6zv";
    };
    dependencies = [];

  };

  vim-multiple-cursors = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-multiple-cursors-2018-07-16";
    src = fetchgit {
      url = "https://github.com/terryma/vim-multiple-cursors";
      rev = "b9e17a51bb2d857f6a5099363232c4fc7715115d";
      sha256 = "0dd9m0a33r4diwykk5nxya199zimn0n4gmp2mi8fnwk6m1f8fwnw";
    };
    dependencies = [];

  };

  vimpreviewpandoc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimpreviewpandoc-2018-05-12";
    src = fetchgit {
      url = "https://github.com/tex/vimpreviewpandoc";
      rev = "266d14d362f6c069863b2d63edb683e802e7e3ee";
      sha256 = "1qhc5vyk7vxrgq11dh1iwkz2a3zd7wfjvyirhhlpx1zx12d6l0ly";
    };
    dependencies = [];

  };

  vim-ft-diff_fold = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-ft-diff_fold-2013-02-10";
    src = fetchgit {
      url = "https://github.com/thinca/vim-ft-diff_fold";
      rev = "89771dffd3682ef82a4b3b3e9c971b9909f08e87";
      sha256 = "0bk95cxkfzamlgv1x2jb1bnfas2pmvvqgpn5fvxddf0andm8sfma";
    };
    dependencies = [];

  };

  vim-prettyprint = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-prettyprint-2016-07-16";
    src = fetchgit {
      url = "https://github.com/thinca/vim-prettyprint";
      rev = "d6060d2b1ff1cff71714e126addd3b10883ade12";
      sha256 = "0mb1ylsq4023ik9wd9iwzlynra2c320xp9h2i79bspapglgd5gk9";
    };
    dependencies = [];

  };

  vim-quickrun = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-quickrun-2018-06-19";
    src = fetchgit {
      url = "https://github.com/thinca/vim-quickrun";
      rev = "825f9f195521646f7001f10cad8627c48017311f";
      sha256 = "0ckcwij5y71dxrga34jxgvf41hs44p4mrd31hbmkz1qrq1i7glpa";
    };
    dependencies = [];

  };

  vim-scouter = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-scouter-2014-08-10";
    src = fetchgit {
      url = "https://github.com/thinca/vim-scouter";
      rev = "5221901d4ad6b2ef8b370b336db2aa7f69f2b6dc";
      sha256 = "0fx64hj1kzrsxz96195d5lm3x88zyycbcr78819mcbgfzyxis6b8";
    };
    dependencies = [];

  };

  vim-themis = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-themis-2017-12-28";
    src = fetchgit {
      url = "https://github.com/thinca/vim-themis";
      rev = "691cd3912ba318dbd8d9fa0035fee629b424766d";
      sha256 = "1mrdaah3iyg35v6cgvr3jav3386czialfcinwa3y9jy14basbqhd";
    };
    dependencies = [];

  };

  molokai = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "molokai-2015-11-11";
    src = fetchgit {
      url = "https://github.com/tomasr/molokai";
      rev = "c67bdfcdb31415aa0ade7f8c003261700a885476";
      sha256 = "1piszjr5kyw43ac1f0jh9z88g824xknshrkchbys9qxlz7pd831s";
    };
    dependencies = [];

  };

  vim-solidity = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-solidity-2018-04-17";
    src = fetchgit {
      url = "https://github.com/tomlion/vim-solidity";
      rev = "569bbbedc3898236d5912fed0caf114936112ae4";
      sha256 = "1qpfbbrm4gjgvbkimhpxyl4fsdqkyw4raf17nw0ibqillz2d3pxx";
    };
    dependencies = [];

  };

  tlib_vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tlib_vim-2018-04-08";
    src = fetchgit {
      url = "https://github.com/tomtom/tlib_vim";
      rev = "ced8f3ebe85b50da2ec0e6d593e6b2e8e6bd243b";
      sha256 = "08vvd1wpa9k5bid2hh279jjkir2c59ga3527qzinxngmlx8wsbhx";
    };
    dependencies = [];

  };

  vim-abolish = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-abolish-2017-03-10";
    src = fetchgit {
      url = "https://github.com/tpope/vim-abolish";
      rev = "b6a8b49e2173ba5a1b34d00e68e0ed8addac3ebd";
      sha256 = "0i9q3l7r5p8mk4in3c1j4x0jbln7ir9lg1cqjxci0chjjzfzc53m";
    };
    dependencies = [];

  };

  vim-commentary = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-commentary-2018-07-11";
    src = fetchgit {
      url = "https://github.com/tpope/vim-commentary";
      rev = "8295187ea1210138c0b171d8e3ec3569936f4c1a";
      sha256 = "1zgbpgl0n11b4jlgx7h7rr1jbgdib7yf8vmh62cxrdj5hrngb6h6";
    };
    dependencies = [];

  };

  vim-dispatch = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-dispatch-2018-07-25";
    src = fetchgit {
      url = "https://github.com/tpope/vim-dispatch";
      rev = "dbb9320d000caa56dfada5f99fe0b5209ef0590b";
      sha256 = "1yqc8fwyf66jckvjf8z8h62399kzgfdzcbnnd9ax8q3wjyk3lfsh";
    };
    dependencies = [];

  };

  vim-eunuch = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-eunuch-2018-07-13";
    src = fetchgit {
      url = "https://github.com/tpope/vim-eunuch";
      rev = "e5f4f955d53e07192fb330ff272604c1b8290532";
      sha256 = "0cv3j3bkapb45ywlfiz8csxmz7gnsdngwgmkrgfg6sljnsgav2za";
    };
    dependencies = [];

  };

  vim-flagship = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-flagship-2018-07-24";
    src = fetchgit {
      url = "https://github.com/tpope/vim-flagship";
      rev = "5e70829913900eb3a37dd6c055ac660c33fa6bff";
      sha256 = "1v2kaisydi1vjfy66bwq2whllbickr3ppp9wqxjqv2qhfsnqny8f";
    };
    dependencies = [];

  };

  vim-fugitive = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-fugitive-2018-07-25";
    src = fetchgit {
      url = "https://github.com/tpope/vim-fugitive";
      rev = "6bab1a0c398a9a6aaef607a5361709393eba79ac";
      sha256 = "1rsiha7a0k7ib455dvxrl46zl7x386i70rhwnbmy8lk6wa32mz7v";
    };
    dependencies = [];

  };

  vim-pathogen = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-pathogen-2018-04-05";
    src = fetchgit {
      url = "https://github.com/tpope/vim-pathogen";
      rev = "06da921608b971fb47603671bcafdb2843992eb3";
      sha256 = "1mxkp2yqqmfl0lq6kmkl716y9x8cdm7aibb376azydxlsbqv4qmi";
    };
    dependencies = [];

  };

  vim-projectionist = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-projectionist-2018-07-24";
    src = fetchgit {
      url = "https://github.com/tpope/vim-projectionist";
      rev = "873e492b4bb92834beb186028fbf6d4e5edfca5a";
      sha256 = "0np7vm97y5ga8gz6qma15awcmgxi41hljp50bgy49sz62z8h0psz";
    };
    dependencies = [];

  };

  vim-repeat = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-repeat-2018-07-02";
    src = fetchgit {
      url = "https://github.com/tpope/vim-repeat";
      rev = "43d2678fa59d068c815d8298331c195e850ff5a7";
      sha256 = "0nb20503ka95qbx0mwhhni15drc86gfcd6kg92nf65llrvyfivk0";
    };
    dependencies = [];

  };

  vim-rhubarb = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-rhubarb-2018-07-21";
    src = fetchgit {
      url = "https://github.com/tpope/vim-rhubarb";
      rev = "848841083d5d4550b5ebbd3bd67dfb3e5146b64a";
      sha256 = "19b36lbsry994y78lnnnjl83q2laz7j6xvk6h6xbl8kj10v6m4l9";
    };
    dependencies = [];

  };

  vim-scriptease = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-scriptease-2018-07-18";
    src = fetchgit {
      url = "https://github.com/tpope/vim-scriptease";
      rev = "baea08bb5fff63cd2adf6e46429cad1f75bc7300";
      sha256 = "01xfnda5paywfsb6ziq00zcgia7ls0v2924i1mcnvnqg4md890x4";
    };
    dependencies = [];

  };

  vim-sensible = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-sensible-2018-07-16";
    src = fetchgit {
      url = "https://github.com/tpope/vim-sensible";
      rev = "c82c6d4978be28adcf85dc1e61fa428e801bd525";
      sha256 = "0w87wic0qx20h36k075lvmj53glxkcyv8hkrx5aw4xqxvbq5fk6q";
    };
    dependencies = [];

  };

  vim-sleuth = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-sleuth-2018-05-24";
    src = fetchgit {
      url = "https://github.com/tpope/vim-sleuth";
      rev = "478e495d40434fb42c655ea2881c8c6b114ecd49";
      sha256 = "1dicdxxfd5sywk02hbpknbr100n96qggy3zy5v520dxdknq0sccz";
    };
    dependencies = [];

  };

  vim-speeddating = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-speeddating-2017-05-24";
    src = fetchgit {
      url = "https://github.com/tpope/vim-speeddating";
      rev = "a418667791f03694065948342f2d6c5cca8d0f32";
      sha256 = "1wm33izawazh0dy70zjk6rkg30yrlldba5r1gypnr4barps702gw";
    };
    dependencies = [];

  };

  vim-surround = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-surround-2018-07-23";
    src = fetchgit {
      url = "https://github.com/tpope/vim-surround";
      rev = "597068870b8f093a8b2d11536c62ff31222ee8d0";
      sha256 = "080kcgb5ayxs49q1p1cms6k1byf2fzzy8bglnspr511m9fql5a9x";
    };
    dependencies = [];

  };

  vim-tbone = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-tbone-2018-06-27";
    src = fetchgit {
      url = "https://github.com/tpope/vim-tbone";
      rev = "8bc7348f658c32bea57365aa6acf3a7dde12e737";
      sha256 = "17s2b66xxkvv17pzf3xrw6ba7y9awpd2k2d21v0pag924c5hi6d4";
    };
    dependencies = [];

  };

  vim-vinegar = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-vinegar-2018-06-20";
    src = fetchgit {
      url = "https://github.com/tpope/vim-vinegar";
      rev = "7b9dff85aec34a0be1a6980b2e686a5d27d70f63";
      sha256 = "033w3wsg5ijwmkq5l1d5r7l0mqfy784sbh8mbjcsx13ndl8fc2g8";
    };
    dependencies = [];

  };

  hasksyn = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "hasksyn-2014-09-03";
    src = fetchgit {
      url = "https://github.com/travitch/hasksyn";
      rev = "c434040bf13a17ca20a551223021b3ace7e453b9";
      sha256 = "09998lnfcshqis5m062wlag6y476imq9jday9gp4ayjjl1cp3cwx";
    };
    dependencies = [];

  };

  vim-haskellconceal = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-haskellconceal-2017-06-15";
    src = fetchgit {
      url = "https://github.com/twinside/vim-haskellconceal";
      rev = "802f82a5afee56e9e1251e6f756104a3bd114234";
      sha256 = "1kh6853hi4rgl4z1xs8kz9l1q9w7lh0r42y2m0rabfpr6yh3091r";
    };
    dependencies = [];

  };

  caw-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "caw-vim-2018-06-16";
    src = fetchgit {
      url = "https://github.com/tyru/caw.vim";
      rev = "e82ae00f3fc03289d4054b44f100025a1bc81939";
      sha256 = "16sbrc34nxbrgpj8gyi1drwh52qg3z2nq4frd5f2nfgxsgjrjjjc";
    };
    dependencies = [];

  };

  open-browser-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "open-browser-vim-2018-04-26";
    src = fetchgit {
      url = "https://github.com/tyru/open-browser.vim";
      rev = "de4eeb085051e9b56dd5574eba7c7e72feb21246";
      sha256 = "1fgp4wwizpknfwscxraqqaxrhvwp9l1mnjwj3llk2x0n9qcqf1db";
    };
    dependencies = [];

  };

  neco-look = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neco-look-2018-01-21";
    src = fetchgit {
      url = "https://github.com/ujihisa/neco-look";
      rev = "4ead88e70f359fb9cef6537ed9c336b7673c1b4c";
      sha256 = "1lszbif7ymdjch1ypnr1nihs6gfbhb86sj6nz3dwrbgsl454nnrj";
    };
    dependencies = [];

  };

  youcompleteme = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "youcompleteme-2018-07-25";
    src = fetchgit {
      url = "https://github.com/valloric/youcompleteme";
      rev = "15362d9cb8ec054c929e9a202252825eabe47e58";
      sha256 = "0nk3wqlz15pvm6hbla8shd3sskbdmwd1x9cq85la223h6s138hwy";
    };
    dependencies = [];
    buildPhase = ''
      substituteInPlace plugin/youcompleteme.vim \
        --replace "'ycm_path_to_python_interpreter', '''" \
                  "'ycm_path_to_python_interpreter', '${python}/bin/python'"

      rm -r third_party/ycmd
      ln -s ${ycmd}/lib/ycmd third_party
    '';

    meta = {
      description = "Fastest non utf-8 aware word and C completion engine for Vim";
      homepage = https://github.com/Valloric/YouCompleteMe;
      license = stdenv.lib.licenses.gpl3;
      maintainers = with stdenv.lib.maintainers; [marcweber jagajaga];
      platforms = stdenv.lib.platforms.unix;
    };
  };

  vim-airline = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-airline-2018-07-24";
    src = fetchgit {
      url = "https://github.com/vim-airline/vim-airline";
      rev = "59f3669a42728406da6d1b948608cae120d1453f";
      sha256 = "12rgvaqfqh0mfv85qdqpr5zn3q3v6npbk11al62fzpa9s55q0025";
    };
    dependencies = [];

  };

  vim-airline-themes = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-airline-themes-2018-06-14";
    src = fetchgit {
      url = "https://github.com/vim-airline/vim-airline-themes";
      rev = "b35f952a6ae6768ae2c6a9f4febc7945cc311f74";
      sha256 = "1j9y9irrzsq1bwp3b22ls016byi0yc9ymigzhw0n180rk6nb36c7";
    };
    dependencies = [];

  };

  vim-pandoc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-pandoc-2018-07-23";
    src = fetchgit {
      url = "https://github.com/vim-pandoc/vim-pandoc";
      rev = "0060e5c6ac9e4a2391e8a36359dcbbb5827978cb";
      sha256 = "0y0ppy1imy4kjkyflxwh5hfp6vcs93xia6myyd5sc6l3gbcg1lrk";
    };
    dependencies = [];

  };

  vim-pandoc-after = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-pandoc-after-2017-11-22";
    src = fetchgit {
      url = "https://github.com/vim-pandoc/vim-pandoc-after";
      rev = "844f27debf4d72811049167f97191a3b551ddfd5";
      sha256 = "0i99g9lnk1xzarw3vzbc47i4bg4iybaywkjvd2krln4q426a6saf";
    };
    dependencies = [];

  };

  vim-pandoc-syntax = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-pandoc-syntax-2017-04-13";
    src = fetchgit {
      url = "https://github.com/vim-pandoc/vim-pandoc-syntax";
      rev = "56e8e41ef863a0a7d33d85c3c0c895aa6e9e62d3";
      sha256 = "19ll4zrw5yd0frgsbi7pg9b68lmy4bfiwbnwgzii7inifrqsykfw";
    };
    dependencies = [];

  };

  vim-ruby = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-ruby-2018-07-08";
    src = fetchgit {
      url = "https://github.com/vim-ruby/vim-ruby";
      rev = "3e0f241b544c63d44ac925ec557ce6735b24d9cf";
      sha256 = "16ywzvb78pxinls0za1bzcds9aznsgvds8q2l4wimp4q9wrs1scs";
    };
    dependencies = [];

  };

  Colour-Sampler-Pack = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Colour-Sampler-Pack-2012-11-29";
    src = fetchgit {
      url = "https://github.com/vim-scripts/Colour-Sampler-Pack";
      rev = "05cded87b2ef29aaa9e930230bb88e23abff4441";
      sha256 = "03v2r18sfgs0xbgy9p56pxfdg0lsk6m7wyr5hw63wm1nzpwiipg3";
    };
    dependencies = [];

  };

  Improved-AnsiEsc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Improved-AnsiEsc-2015-08-25";
    src = fetchgit {
      url = "https://github.com/vim-scripts/Improved-AnsiEsc";
      rev = "e1c59a8e9203fab6b9150721f30548916da73351";
      sha256 = "1smjs4kz2kmzprzp9az4957675nakb43146hshbby39j5xz4jsbz";
    };
    dependencies = [];

  };

  Rename = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Rename-2011-08-30";
    src = fetchgit {
      url = "https://github.com/vim-scripts/Rename";
      rev = "b240f28d2ede65fa77cd99fe045efe79202f7a34";
      sha256 = "1d1myg4zyc281zcc1ba9idbgcgxndb4a0jwqr4yqxhhzdgszw46r";
    };
    dependencies = [];

  };

  ReplaceWithRegister = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ReplaceWithRegister-2014-10-30";
    src = fetchgit {
      url = "https://github.com/vim-scripts/ReplaceWithRegister";
      rev = "832efc23111d19591d495dc72286de2fb0b09345";
      sha256 = "0mb0sx85j1k59b1zz95r4vkq4kxlb4krhncq70mq7fxrs5bnhq8g";
    };
    dependencies = [];

  };

  YankRing-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "YankRing-vim-2015-07-28";
    src = fetchgit {
      url = "https://github.com/vim-scripts/YankRing.vim";
      rev = "28854abef8fa4ebd3cb219aefcf22566997d8f65";
      sha256 = "0zdp8pdsqgrh6lfw8ipjhrig6psvmdxkim9ik801y3r373sk2hxw";
    };
    dependencies = [];

  };

  a-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "a-vim-2010-11-06";
    src = fetchgit {
      url = "https://github.com/vim-scripts/a.vim";
      rev = "2cbe946206ec622d9d8cf2c99317f204c4d41885";
      sha256 = "0h62v9z5bh9xmaq22pqdb3z79i84a5rknqm68mjpy7nq7s3q42fa";
    };
    dependencies = [];

  };

  align = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "align-2012-08-07";
    src = fetchgit {
      url = "https://github.com/vim-scripts/align";
      rev = "787662fe90cd057942bc5b682fd70c87e1a9dd77";
      sha256 = "0acacr572kfh7jvavbw61q5pkwrpi1albgancma063rpax1pddgp";
    };
    dependencies = [];

  };

  argtextobj-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "argtextobj-vim-2010-10-17";
    src = fetchgit {
      url = "https://github.com/vim-scripts/argtextobj.vim";
      rev = "f3fbe427f7b4ec436416a5816d714dc917dc530b";
      sha256 = "1l4jh5hdmky1qj5z26jpnk49a6djjcvzyyr6pknrrgb8rzkiln48";
    };
    dependencies = [];

  };

  bats-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "bats-vim-2013-07-03";
    src = fetchgit {
      url = "https://github.com/vim-scripts/bats.vim";
      rev = "3c283f594ff8bc7fb0c25cd07ebef0f17385f94a";
      sha256 = "06f3hdf7y5gpwmc6inrhk938qmn7cr6mbk00amrnl1qjvk09givx";
    };
    dependencies = [];

  };

  changeColorScheme-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "changeColorScheme-vim-2010-10-17";
    src = fetchgit {
      url = "https://github.com/vim-scripts/changeColorScheme.vim";
      rev = "b041d49f828629d72f2232531a230d1ec5de2405";
      sha256 = "0pybhsg9k9252d4ifdc4gsar8lkmfzbvs6xkzqq1m6f35l9wqk09";
    };
    dependencies = [];

  };

  matchit-zip = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "matchit-zip-2010-10-17";
    src = fetchgit {
      url = "https://github.com/vim-scripts/matchit.zip";
      rev = "ced6c409c9beeb0b4142d21906606bd194411d1d";
      sha256 = "1s9c4lnsmbfm97bp22jrmcp5lga5ihx23lzqqncvv7rcizkvr3dm";
    };
    dependencies = [];

  };

  mayansmoke-git = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "mayansmoke-git-2010-10-17";
    src = fetchgit {
      url = "https://github.com/vim-scripts/mayansmoke.git";
      rev = "168883af7aec05f139af251f47eadd5dfb802c9d";
      sha256 = "1xxcky7i6sx7f1q8xka4gd2xg78w6sqjvqrdwgrdzv93fhf82rpd";
    };
    dependencies = [];

  };

  random-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "random-vim-2010-10-17";
    src = fetchgit {
      url = "https://github.com/vim-scripts/random.vim";
      rev = "b2d85eb24a38074eab37a5acf2a295e1f2ad8989";
      sha256 = "1lzy2cq4jcrsqyxlnbnd0y6j4mabm09bi7q22lf6vinqlb84w7sp";
    };
    dependencies = [];

  };

  tabmerge = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tabmerge-2010-10-17";
    src = fetchgit {
      url = "https://github.com/vim-scripts/tabmerge";
      rev = "074e5f06f26e7108a0570071a0f938a821768c06";
      sha256 = "0prkyza1n49cdaslcr57w8zv15vw78mlqbzib2xipmawzjq02idq";
    };
    dependencies = [];

  };

  taglist-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "taglist-vim-2010-10-17";
    src = fetchgit {
      url = "https://github.com/vim-scripts/taglist.vim";
      rev = "53041fbc45398a9af631a20657e109707a455339";
      sha256 = "07aa2gfc73lznyi7w7cybzanspza3p67cv5hxr21g43zhs5k9izd";
    };
    dependencies = [];

  };

  wombat256-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "wombat256-vim-2010-10-17";
    src = fetchgit {
      url = "https://github.com/vim-scripts/wombat256.vim";
      rev = "8734ba45dcf5e38c4d2686b35c94f9fcb30427e2";
      sha256 = "01fdvfwdfqn5xi88lfanb4lb6jmn1ma6wq6d9jj2x7qamdbpvsrg";
    };
    dependencies = [];

  };

  vimoutliner = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimoutliner-2018-07-04";
    src = fetchgit {
      url = "https://github.com/vimoutliner/vimoutliner";
      rev = "aad0a213069b8a1b5de91cca07d153fc8352c957";
      sha256 = "0pgkgs6xky0skhpp3s9vrw3h48j80im0j39q4vc2b3pd1ydy6rx2";
    };
    dependencies = [];

  };

  vimwiki = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimwiki-2018-07-21";
    src = fetchgit {
      url = "https://github.com/vimwiki/vimwiki";
      rev = "9f797f6ad9fd2a5e943bc99b5f9cd44b2cbd0fb4";
      sha256 = "0snqxbfpc9jy9zy3n0g2xc01kgxznnnd0g00v2nb17vs3m1b7arc";
    };
    dependencies = [];

  };

  dhall-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "dhall-vim-2018-07-23";
    src = fetchgit {
      url = "https://github.com/vmchale/dhall-vim";
      rev = "5bdddb86e660f172841109a28e2a98efb76448ce";
      sha256 = "0rkzgn5ny84624q7phc8wdm4nvkq2ypkq5lkbmahhm26cxvlkqlq";
    };
    dependencies = [];

  };

  ale = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ale-2018-07-25";
    src = fetchgit {
      url = "https://github.com/w0rp/ale";
      rev = "79ffdde267323a206a96227904549c370f27decf";
      sha256 = "02np0jnz50qs3fl6n0wh1xfzgq8lbfgagf2mw8cbj8a4gmzx67fg";
    };
    dependencies = [];

  };

  vim-wakatime = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-wakatime-2018-07-14";
    src = fetchgit {
      url = "https://github.com/wakatime/vim-wakatime";
      rev = "25aa400fd1f1e3d689c721605a65e015024dc4cf";
      sha256 = "11lk5k8wl3kxp6p2i0nnp56f4wcaniy40kzs3anjdwlzya631rg2";
    };
    dependencies = [];
    buildInputs = [ python ];
  };

  targets-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "targets-vim-2018-05-27";
    src = fetchgit {
      url = "https://github.com/wellle/targets.vim";
      rev = "c3042dc18acc0dfcee479310d3efc6aefe92db75";
      sha256 = "0shnlgwrxzrd0m3k6hnmr66i2l4zknp0pn7f71d2frx937gih34q";
    };
    dependencies = [];

  };

  vim-dirdiff = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-dirdiff-2018-01-30";
    src = fetchgit {
      url = "https://github.com/will133/vim-dirdiff";
      rev = "b5a3d59bfbeb5cef7dbadbe69c455b470988b58c";
      sha256 = "16hc88k00xa757k0h53r1sbqwxdxdy0118yl2vsigd6rqk474nw1";
    };
    dependencies = [];

  };

  command-t = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "command-t-2017-11-16";
    src = fetchgit {
      url = "https://github.com/wincent/command-t";
      rev = "7147ba92c9c1eef8269fd47d47ba636ce7f365a6";
      sha256 = "171z1jjjv1l15rh3i2hc400vjf4zns8sjvda0vcjkx2717ax658r";
    };
    dependencies = [];
    buildInputs = [ ruby rake ];
    buildPhase = ''
      rake make
      rm ruby/command-t/ext/command-t/*.o
    '';
  };

  vim-easytags = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-easytags-2015-07-01";
    src = fetchgit {
      url = "https://github.com/xolox/vim-easytags";
      rev = "72a8753b5d0a951e547c51b13633f680a95b5483";
      sha256 = "0i8ha1fa5d860b1mi0xp8kwsgb0b9vbzcg1bldzv6s5xd9yyi12i";
    };
    dependencies = ["vim-misc"];

  };

  vim-misc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-misc-2015-05-21";
    src = fetchgit {
      url = "https://github.com/xolox/vim-misc";
      rev = "3e6b8fb6f03f13434543ce1f5d24f6a5d3f34f0b";
      sha256 = "0rd9788dyfc58py50xbiaz5j7nphyvf3rpp3yal7yq2dhf0awwfi";
    };
    dependencies = [];

  };

  vim-latex-live-preview = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-latex-live-preview-2017-11-09";
    src = fetchgit {
      url = "https://github.com/xuhdev/vim-latex-live-preview";
      rev = "9855f084d0751dbd40a8cb56518f239e5eb1a624";
      sha256 = "0linzdq2zrz5yfpqa51n2i9vrwr0x2r93ckx6n1ngyiw535ddafy";
    };
    dependencies = [];

  };

  nim-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "nim-vim-2018-05-20";
    src = fetchgit {
      url = "https://github.com/zah/nim.vim";
      rev = "704dd5d63cac54c22fe25c6efbcf18796df412e7";
      sha256 = "0azk3m33c47ja24iirlrjqphmd8rzlivinqkx69izmd7l150ds2m";
    };
    dependencies = [];

  };

  deoplete-go = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "deoplete-go-2018-07-03";
    src = fetchgit {
      url = "https://github.com/zchee/deoplete-go";
      rev = "2d402d856d98d4a351fdcf40d837da0cf52ccdfd";
      sha256 = "0hj5bhfhd9am11ixaxad370p982bjig53mbm74fi6slhjpikdrdq";
    };
    dependencies = [];
    buildInputs = [ python3 ];
    buildPhase = ''
      pushd ./rplugin/python3/deoplete/ujson
      python3 setup.py build --build-base=$PWD/build --build-lib=$PWD/build
      popd
      find ./rplugin/ -name "ujson*.so" -exec mv -v {} ./rplugin/python3/ \;
    '';
  };

  deoplete-jedi = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "deoplete-jedi-2018-07-10";
    src = fetchgit {
      url = "https://github.com/zchee/deoplete-jedi";
      rev = "5540e76ee3194f2eaa2df51945297cb847a1dfa8";
      sha256 = "0mqq42v4l2y0hkcs83j0cp7hxamv6gn5g8z4bccrbssgrsv61cg6";
    };
    dependencies = [];

  };

  zig-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "zig-vim-2018-07-18";
    src = fetchgit {
      url = "https://github.com/zig-lang/zig.vim";
      rev = "2dc38afd6af04ea563a0d0d6f61891b5c820e8fe";
      sha256 = "1nyrg87biwq6b3jk40fyjd5mlnl4pbvwsqi9095y8gjanf9a9dck";
    };
    dependencies = [];

  };

} // lib.optionalAttrs (config.allowAliases or true) (with self; {

  # aliasess
  airline             = vim-airline;
  alternative         = a-vim; # backwards compat, added 2014-10-21
  bats                = bats-vim;
  calendar            = calendar-vim;
  coffee-script       = vim-coffee-script;
  coffeeScript        = coffee-script; # backwards compat, added 2014-10-18
  Solarized           = vim-colors-solarized;
  solarized           = vim-colors-solarized;
  colors-solarized    = vim-colors-solarized;
  caw                 = caw-vim;
  colorsamplerpack    = Colour_Sampler_Pack;
  Colour_Sampler_Pack = Colour-Sampler-Pack;
  command_T           = command-t; # backwards compat, added 2014-10-18
  commentary          = vim-commentary;
  committia           = committia-vim-git;
  concealedyank       = concealedyank-vim;
  context-filetype    = context_filetype-vim;
  Cosco               = cosco-vim;
  css_color_5056      = vim-css-color;
  CSApprox            = csapprox;
  csv                 = csv-vim;
  ctrlp               = ctrlp-vim;
  cute-python         = vim-cute-python-git;
  denite              = denite-nvim;
  easy-align          = vim-easy-align;
  easygit             = vim-easygit;
  easymotion          = vim-easymotion;
  echodoc             = echodoc-vim;
  eighties            = vim-eighties;
  extradite           = vim-extradite;
  fugitive            = vim-fugitive;
  ghc-mod-vim         = ghcmod-vim;
  ghcmod              = ghcmod-vim;
  goyo                = goyo-vim;
  Gist                = gist-vim;
  gitgutter           = vim-gitgutter;
  gundo               = gundo-vim;
  Gundo               = gundo-vim; # backwards compat, added 2015-10-03
  haskellConceal      = haskellconceal; # backwards compat, added 2014-10-18
  haskellConcealPlus  = vim-haskellConcealPlus;
  haskellconceal      = vim-haskellconceal;
  hier                = vim-hier;
  hlint-refactor      = hlint-refactor-vim;
  hoogle              = vim-hoogle;
  Hoogle              = vim-hoogle;
  ipython             = vim-ipython;
  latex-live-preview  = vim-latex-live-preview;
  maktaba             = vim-maktaba;
  mayansmoke          = mayansmoke-git;
  multiple-cursors    = vim-multiple-cursors;
  necoGhc             = neco-ghc; # backwards compat, added 2014-10-18
  neocomplete         = neocomplete-vim;
  neoinclude          = neoinclude-vim;
  neomru              = neomru-vim;
  neosnippet          = neosnippet-vim;
  neoyank             = neoyank-vim-git;
  The_NERD_Commenter  = nerdcommenter;
  The_NERD_tree       = nerdtree;
  open-browser        = open-browser-vim;
  pathogen            = vim-pathogen;
  peskcolor           = peskcolor-vim-git;
  polyglot            = vim-polyglot;
  prettyprint         = vim-prettyprint;
  quickrun            = vim-quickrun;
  rainbow_parentheses = rainbow_parentheses-vim;
  repeat              = vim-repeat;
  riv                 = riv-vim;
  rhubarb             = vim-rhubarb;
  sensible            = vim-sensible;
  signature           = vim-signature;
  snipmate            = vim-snipmate;
  sourcemap           = sourcemap-vim;
  "sourcemap.vim"     = sourcemap-vim;
  surround            = vim-surround;
  sleuth              = vim-sleuth;
  solidity            = vim-solidity;
  stylish-haskell     = vim-stylish-haskell;
  stylishHaskell      = stylish-haskell; # backwards compat, added 2014-10-18
  Supertab            = supertab;
  Syntastic           = syntastic;
  SyntaxRange         = vim-SyntaxRange;
  table-mode          = vim-table-mode;
  taglist             = taglist-vim;
  tabpagebuffer       = tabpagebuffer-vim;
  tabpagecd           = vim-tabpagecd;
  Tabular             = tabular;
  Tagbar              = tagbar;
  thumbnail           = thumbnail-vim;
  tlib                = tlib_vim;
  tmux-navigator      = vim-tmux-navigator;
  tmuxNavigator       = tmux-navigator; # backwards compat, added 2014-10-18
  tslime              = tslime-vim;
  unite               = unite-vim;
  UltiSnips           = ultisnips;
  vim-grepper         = vim-grepper-git;
  vim-test            = vim-test-git;
  vimproc             = vimproc-vim;
  vimshell            = vimshell-vim;
  vinegar             = vim-vinegar;
  watchdogs           = vim-watchdogs;
  WebAPI              = webapi-vim;
  wombat256           = wombat256-vim; # backwards compat, added 2015-7-8
  yankring            = YankRing-vim;
  Yankring            = YankRing-vim;
  YouCompleteMe       = youcompleteme;
  xterm-color-table   = xterm-color-table-vim;
  zeavim              = zeavim-vim;
});
in self
